"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QQuickImageResponse(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qquickimageresponse.html

    **Detailed Description**

    The purpose of an image response is to provide a way for image provider jobs
    to be executed in an asynchronous way.

    Responses are deleted via **deleteLater**  once the **finished** () signal
    has been emitted. If you are using **QRunnable**  as base for your
    QQuickImageResponse ensure automatic deletion is disabled.

    See the **Image Response Provider Example**  for a complete implementation.

    **See also** **QQuickImageProvider** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickimageresponse.html#QQuickImageResponse

        **QQuickImageResponse::QQuickImageResponse()**

        Constructs the image response
        """
        ...

    def cancel(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickimageresponse.html#cancel

        **[virtual slot] void QQuickImageResponse::cancel()**

        This method is used to communicate that the response is no longer
        required by the engine.

        It may be reimplemented to cancel a request in the provider side,
        however, it is not mandatory.

        A cancelled **QQuickImageResponse**  still needs to emit **finished** ()
        so that the engine may clean up the **QQuickImageResponse** .

        **Note:****finished** () should not be emitted until the response is
        complete, regardless of whether or not cancel() was called. If it is
        called prematurely, the engine may destroy the response while it is
        still active, leading to a crash.
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qquickimageresponse.html#errorString

        **[virtual] QString QQuickImageResponse::errorString() const**

        Returns the error string for the job execution. An empty string means no
        error.
        """
        ...

    def textureFactory(self) -> QQuickTextureFactory:
        """
        https://doc.qt.io/qt-6/qquickimageresponse.html#textureFactory

        **[pure virtual] QQuickTextureFactory
        *QQuickImageResponse::textureFactory() const**

        Returns the texture factory for the job. You can use
        **QQuickTextureFactory::textureFactoryForImage**  if your provider works
        with **QImage** . The engine takes ownership of the returned
        **QQuickTextureFactory** .

        **Note:** This method will be called only when needed. For example, it
        may not be called if there is an error or the job is cancelled.
        Therefore, allocate the **QQuickTextureFactory**  instance only in this
        method or otherwise ensure its deletion.
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qquickimageresponse.html#finished

        **[signal] void QQuickImageResponse::finished()**

        Signals that the job execution has finished (be it successfully, because
        an error happened or because it was cancelled).

        **Note:** Emission of this signal must be the final action the response
        performs: once the signal is received, the response will subsequently be
        destroyed by the engine.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QLayout(QtCore.QObject, QLayoutItem):
    """
    https://doc.qt.io/qt-6/qlayout.html

    **Detailed Description**

    This is an abstract base class inherited by the concrete classes
    **QBoxLayout** , **QGridLayout** , **QFormLayout** , and **QStackedLayout**
    .

    For users of QLayout subclasses or of **QMainWindow**  there is seldom any
    need to use the basic functions provided by QLayout, such as
    **setSizeConstraint** () or **setMenuBar** (). See **Layout Management**
    for more information.

    To make your own layout manager, implement the functions **addItem** (),
    **sizeHint** (), **setGeometry** (), **itemAt** () and **takeAt** (). You
    should also implement **minimumSize** () to ensure your layout isn't resized
    to zero size if there is too little space. To support children whose heights
    depend on their widths, implement **hasHeightForWidth** () and
    **heightForWidth** (). See the **Border Layout**  and **Flow Layout**
    examples for more information about implementing custom layout managers.

    Geometry management stops when the layout manager is deleted.

    **See also** **QLayoutItem** , **Layout Management** , **Basic Layouts
    Example** , **Border Layout Example** , and **Flow Layout Example** .
    """

    class SizeConstraint(enum.Enum):
        SetDefaultConstraint: QLayout = ...
        SetNoConstraint: QLayout = ...
        SetMinimumSize: QLayout = ...
        SetFixedSize: QLayout = ...
        SetMaximumSize: QLayout = ...
        SetMinAndMaxSize: QLayout = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#QLayout

        **QLayout::QLayout(QWidget * parent = nullptr)**

        Constructs a new top-level QLayout, with parent **parent**.

        The layout is set directly as the top-level layout for **parent**. There
        can be only one top-level layout for a widget. It is returned by
        **QWidget::layout** ().

        If **parent** is `nullptr`, then you must insert this layout into
        another layout, or set it as a widget's layout using
        **QWidget::setLayout** ().

        **See also** **QWidget::setLayout** ().
        """
        ...

    def unsetContentsMargins(self) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#unsetContentsMargins

        **[since 6.1] void QLayout::unsetContentsMargins()**

        Unsets any user-defined margins around the layout. The layout will use
        the default values provided by the style.

        **Note:** Resetter function for property **contentsMargins** .

        This function was introduced in Qt 6.1.

        **See also** **setContentsMargins** ().
        """
        ...

    def replaceWidget(
        self, from_: QWidget, to: QWidget, options: QtCore.Qt.FindChildOption = ...
    ) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qlayout.html#replaceWidget

        **[virtual, since 5.2] QLayoutItem *QLayout::replaceWidget(QWidget *
        from , QWidget * to , Qt::FindChildOptions options =
        Qt::FindChildrenRecursively)**

        Searches for widget **from** and replaces it with widget **to** if
        found. Returns the layout item that contains the widget **from** on
        success. Otherwise `nullptr` is returned. If **options** contains
        `Qt::FindChildrenRecursively` (the default), sub-layouts are searched
        for doing the replacement. Any other flag in **options** is ignored.

        Notice that the returned item therefore might not belong to this layout,
        but to a sub-layout.

        The returned layout item is no longer owned by the layout and should be
        either deleted or inserted to another layout. The widget **from** is no
        longer managed by the layout and may need to be deleted or hidden. The
        parent of widget **from** is left unchanged.

        This function works for the built-in Qt layouts, but might not work for
        custom layouts.

        This function was introduced in Qt 5.2.

        **See also** **indexOf** ().
        """
        ...

    def controlTypes(self) -> "QSizePolicy.ControlType":
        """
        https://doc.qt.io/qt-6/qlayout.html#controlTypes

        **[override virtual] QSizePolicy::ControlTypes QLayout::controlTypes()
        const**

        Reimplements: **QLayoutItem::controlTypes() const** .
        """
        ...

    def contentsMargins(self) -> QtCore.QMargins:
        """
        https://doc.qt.io/qt-6/qlayout.html#contentsMargins

        **QMargins QLayout::contentsMargins() const**

        Returns the margins used around the layout.

        By default, **QLayout**  uses the values provided by the style. On most
        platforms, the margin is 11 pixels in all directions.

        **Note:** Getter function for property contentsMargins.

        **See also** **setContentsMargins** ().
        """
        ...

    def contentsRect(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qlayout.html#contentsRect

        **QRect QLayout::contentsRect() const**

        Returns the layout's **geometry** () rectangle, but taking into account
        the contents margins.

        **See also** **setContentsMargins** () and **getContentsMargins** ().
        """
        ...

    def getContentsMargins(self) -> typing.Tuple[int, int, int, int]:
        """
        https://doc.qt.io/qt-6/qlayout.html#getContentsMargins

        **void QLayout::getContentsMargins(int * left , int * top , int * right
        , int * bottom ) const**

        For each of **left** , **top** , **right** and **bottom** that is not
        `nullptr`, stores the size of the margin named in the location the
        pointer refers to.

        By default, **QLayout**  uses the values provided by the style. On most
        platforms, the margin is 11 pixels in all directions.

        **See also** **setContentsMargins** (), **QStyle::pixelMetric** (),
        **PM_LayoutLeftMargin** , **PM_LayoutTopMargin** ,
        **PM_LayoutRightMargin** , and **PM_LayoutBottomMargin** .
        """
        ...

    @typing.overload
    def setContentsMargins(self, left: int, top: int, right: int, bottom: int) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#setContentsMargins

        **void QLayout::setContentsMargins(int left , int top , int right , int
        bottom )**

        Sets the **left** , **top** , **right** , and **bottom** margins to use
        around the layout.

        By default, **QLayout**  uses the values provided by the style. On most
        platforms, the margin is 11 pixels in all directions.

        **Note:** Setter function for property **contentsMargins** .

        **See also** **contentsMargins** (), **getContentsMargins** (),
        **QStyle::pixelMetric** (), **PM_LayoutLeftMargin** ,
        **PM_LayoutTopMargin** , **PM_LayoutRightMargin** , and
        **PM_LayoutBottomMargin** .
        """
        ...

    @typing.overload
    def setContentsMargins(self, margins: QtCore.QMargins) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#setContentsMargins-1

        **void QLayout::setContentsMargins(const QMargins & margins )**

        Sets the **margins** to use around the layout.

        By default, **QLayout**  uses the values provided by the style. On most
        platforms, the margin is 11 pixels in all directions.

        **Note:** Setter function for property **contentsMargins** .

        **See also** **contentsMargins** ().
        """
        ...

    def alignmentRect(self, a0: QtCore.QRect) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qlayout.html#alignmentRect

        **[protected] QRect QLayout::alignmentRect(const QRect & r ) const**

        Returns the rectangle that should be covered when the geometry of this
        layout is set to **r** , provided that this layout supports
        **setAlignment** ().

        The result is derived from **sizeHint** () and expanding(). It is never
        larger than **r**.
        """
        ...

    def addChildWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#addChildWidget

        **[protected] void QLayout::addChildWidget(QWidget * w )**

        This function is called from `addWidget()` functions in subclasses to
        add **w** as a managed widget of a layout.

        If **w** is already managed by a layout, this function will give a
        warning and remove **w** from that layout. This function must therefore
        be called before adding **w** to the layout's data structure.
        """
        ...

    def addChildLayout(self, l: "QLayout") -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#addChildLayout

        **[protected] void QLayout::addChildLayout(QLayout * l )**

        This function is called from `addLayout()` or `insertLayout()` functions
        in subclasses to add layout **l** as a sub-layout.

        The only scenario in which you need to call it directly is if you
        implement a custom layout that supports nested layouts.

        **See also** **QBoxLayout::addLayout** (), **QBoxLayout::insertLayout**
        (), and **QGridLayout::addLayout** ().
        """
        ...

    def childEvent(self, e: QtCore.QChildEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#childEvent

        **[override virtual protected] void QLayout::childEvent(QChildEvent * e
        )**

        Reimplements: **QObject::childEvent** (QChildEvent *event).
        """
        ...

    def widgetEvent(self, a0: QtCore.QEvent) -> None:
        ...

    @staticmethod
    def closestAcceptableSize(w: QWidget, s: QtCore.QSize) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlayout.html#closestAcceptableSize

        **[static] QSize QLayout::closestAcceptableSize(const QWidget * widget ,
        const QSize & size )**

        Returns a size that satisfies all size constraints on **widget** ,
        including **heightForWidth** () and that is as close as possible to
        **size**.
        """
        ...

    def isEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlayout.html#isEnabled

        **bool QLayout::isEnabled() const**

        Returns `true` if the layout is enabled; otherwise returns `false`.

        **See also** **setEnabled** ().
        """
        ...

    def setEnabled(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#setEnabled

        **void QLayout::setEnabled(bool enable )**

        Enables this layout if **enable** is true, otherwise disables it.

        An enabled layout adjusts dynamically to changes; a disabled layout acts
        as if it did not exist.

        By default all layouts are enabled.

        **See also** **isEnabled** ().
        """
        ...

    def layout(self) -> "QLayout":
        """
        https://doc.qt.io/qt-6/qlayout.html#layout

        **[override virtual] QLayout *QLayout::layout()**

        Reimplements: **QLayoutItem::layout** ().
        """
        ...

    def totalSizeHint(self) -> QtCore.QSize:
        ...

    def totalMaximumSize(self) -> QtCore.QSize:
        ...

    def totalMinimumSize(self) -> QtCore.QSize:
        ...

    def totalHeightForWidth(self, w: int) -> int:
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlayout.html#isEmpty

        **[override virtual] bool QLayout::isEmpty() const**

        Reimplements: **QLayoutItem::isEmpty() const** .
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qlayout.html#count

        **[pure virtual] int QLayout::count() const**

        Must be implemented in subclasses to return the number of items in the
        layout.

        **See also** **itemAt** ().
        """
        ...

    @typing.overload
    def indexOf(self, a0: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qlayout.html#indexOf

        **[virtual] int QLayout::indexOf(const QWidget * widget ) const**

        Searches for widget **widget** in this layout (not including child
        layouts).

        Returns the index of **widget** , or -1 if **widget** is not found.

        The default implementation iterates over all items using **itemAt** ().
        """
        ...

    @typing.overload
    def indexOf(self, a0: QLayoutItem) -> int:
        """
        https://doc.qt.io/qt-6/qlayout.html#indexOf-1

        **[virtual, since 5.12] int QLayout::indexOf(const QLayoutItem *
        layoutItem ) const**

        Searches for layout item **layoutItem** in this layout (not including
        child layouts).

        Returns the index of **layoutItem** , or -1 if **layoutItem** is not
        found.

        This function was introduced in Qt 5.12.
        """
        ...

    def takeAt(self, index: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qlayout.html#takeAt

        **[pure virtual] QLayoutItem *QLayout::takeAt(int index )**

        Must be implemented in subclasses to remove the layout item at **index**
        from the layout, and return the item. If there is no such item, the
        function must do nothing and return 0. Items are numbered consecutively
        from 0. If an item is removed, other items will be renumbered.

        The following code fragment shows a safe way to remove all items from a
        layout:

        **QLayoutItem**  *child;
            while ((child = layout->takeAt(0)) !=
        nullptr) {
                ...
                delete child->widget(); // delete the
        widget
                delete child;   // delete the layout item
            }

        **See also** **itemAt** () and **count** ().
        """
        ...

    def itemAt(self, index: int) -> QLayoutItem:
        """
        https://doc.qt.io/qt-6/qlayout.html#itemAt

        **[pure virtual] QLayoutItem *QLayout::itemAt(int index ) const**

        Must be implemented in subclasses to return the layout item at
        **index**. If there is no such item, the function must return `nullptr`.
        Items are numbered consecutively from 0. If an item is deleted, other
        items will be renumbered.

        This function can be used to iterate over a layout. The following code
        will draw a rectangle for each layout item in the layout structure of
        the widget.

        static void paintLayout(**QPainter**  *painter, **QLayoutItem**  *item)
        {
                **QLayout**  *layout = item->layout();
                if (layout) {
        for (int i = 0; i < layout->count(); ++i)
        paintLayout(painter, layout->itemAt(i));
                }
        painter->drawRect(item->geometry());
            }

            void
        MyWidget::paintEvent(**QPaintEvent**  *)
            {
                **QPainter**
        painter(this);
                if (layout())
                    paintLayout(&painter,
        layout());
            }

        **See also** **count** () and **takeAt** ().
        """
        ...

    def setGeometry(self, a0: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#setGeometry

        **[override virtual] void QLayout::setGeometry(const QRect & r )**

        Reimplements: **QLayoutItem::setGeometry** (const QRect &r).

        **See also** **geometry** ().
        """
        ...

    def maximumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlayout.html#maximumSize

        **[override virtual] QSize QLayout::maximumSize() const**

        Reimplements: **QLayoutItem::maximumSize() const** .

        Returns the maximum size of this layout. This is the largest size that
        the layout can have while still respecting the specifications.

        The returned value doesn't include the space required by
        **QWidget::setContentsMargins** () or **menuBar** ().

        The default implementation allows unlimited resizing.
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlayout.html#minimumSize

        **[override virtual] QSize QLayout::minimumSize() const**

        Reimplements: **QLayoutItem::minimumSize() const** .

        Returns the minimum size of this layout. This is the smallest size that
        the layout can have while still respecting the specifications.

        The returned value doesn't include the space required by
        **QWidget::setContentsMargins** () or **menuBar** ().

        The default implementation allows unlimited resizing.
        """
        ...

    def expandingDirections(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qlayout.html#expandingDirections

        **[override virtual] Qt::Orientations QLayout::expandingDirections()
        const**

        Reimplements: **QLayoutItem::expandingDirections() const** .

        Returns whether this layout can make use of more space than **sizeHint**
        (). A value of **Qt::Vertical**  or **Qt::Horizontal**  means that it
        wants to grow in only one dimension, whereas **Qt::Vertical**  |
        **Qt::Horizontal**  means that it wants to grow in both dimensions.

        The default implementation returns **Qt::Horizontal**  |
        **Qt::Vertical** . Subclasses reimplement it to return a meaningful
        value based on their child widgets's **size policies** .

        **See also** **sizeHint** ().
        """
        ...

    def removeItem(self, a0: QLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#removeItem

        **void QLayout::removeItem(QLayoutItem * item )**

        Removes the layout item **item** from the layout. It is the caller's
        responsibility to delete the item.

        Notice that **item** can be a layout (since **QLayout**  inherits
        **QLayoutItem** ).

        **See also** **removeWidget** () and **addItem** ().
        """
        ...

    def removeWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#removeWidget

        **void QLayout::removeWidget(QWidget * widget )**

        Removes the widget **widget** from the layout. After this call, it is
        the caller's responsibility to give the widget a reasonable geometry or
        to put the widget back into a layout or to explicitly hide it if
        necessary.

        **Note:** The ownership of **widget** remains the same as when it was
        added.

        **See also** **removeItem** (), **QWidget::setGeometry** (), and
        **addWidget** ().
        """
        ...

    def addItem(self, a0: QLayoutItem) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#addItem

        **[pure virtual] void QLayout::addItem(QLayoutItem * item )**

        Implemented in subclasses to add an **item**. How it is added is
        specific to each subclass.

        This function is not usually called in application code. To add a widget
        to a layout, use the **addWidget** () function; to add a child layout,
        use the addLayout() function provided by the relevant **QLayout**
        subclass.

        **Note:** The ownership of **item** is transferred to the layout, and
        it's the layout's responsibility to delete it.

        **See also** **addWidget** (), **QBoxLayout::addLayout** (), and
        **QGridLayout::addLayout** ().
        """
        ...

    def addWidget(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#addWidget

        **void QLayout::addWidget(QWidget * w )**

        Adds widget **w** to this layout in a manner specific to the layout.
        This function uses **addItem** ().
        """
        ...

    def update(self) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#update

        **void QLayout::update()**

        Updates the layout for **parentWidget** ().

        You should generally not need to call this because it is automatically
        called at the most appropriate times.

        **See also** **activate** () and **invalidate** ().
        """
        ...

    def activate(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlayout.html#activate

        **bool QLayout::activate()**

        Redoes the layout for **parentWidget** () if necessary.

        You should generally not need to call this because it is automatically
        called at the most appropriate times. It returns true if the layout was
        redone.

        **See also** **update** () and **QWidget::updateGeometry** ().
        """
        ...

    def geometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qlayout.html#geometry

        **[override virtual] QRect QLayout::geometry() const**

        Reimplements: **QLayoutItem::geometry() const** .

        **See also** **setGeometry** ().
        """
        ...

    def invalidate(self) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#invalidate

        **[override virtual] void QLayout::invalidate()**

        Reimplements: **QLayoutItem::invalidate** ().
        """
        ...

    def parentWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qlayout.html#parentWidget

        **QWidget *QLayout::parentWidget() const**

        Returns the parent widget of this layout, or `nullptr` if this layout is
        not installed on any widget.

        If the layout is a sub-layout, this function returns the parent widget
        of the parent layout.

        **See also** **parent** ().
        """
        ...

    def menuBar(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qlayout.html#menuBar

        **QWidget *QLayout::menuBar() const**

        Returns the menu bar set for this layout, or `nullptr` if no menu bar is
        set.

        **See also** **setMenuBar** ().
        """
        ...

    def setMenuBar(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#setMenuBar

        **void QLayout::setMenuBar(QWidget * widget )**

        Tells the geometry manager to place the menu bar **widget** at the top
        of **parentWidget** (), outside **QWidget::contentsMargins** (). All
        child widgets are placed below the bottom edge of the menu bar.

        **See also** **menuBar** ().
        """
        ...

    def sizeConstraint(self) -> "QLayout.SizeConstraint":
        """
        https://doc.qt.io/qt-6/qlayout.html#sizeConstraint-prop

        **sizeConstraint : SizeConstraint**

        This property holds the resize mode of the layout

        The default mode is **SetDefaultConstraint** .

        **Access functions:**

        QLayout::SizeConstraint **sizeConstraint** () const
        void
        **setSizeConstraint** (QLayout::SizeConstraint)
        """
        ...

    def setSizeConstraint(self, a0: "QLayout.SizeConstraint") -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#sizeConstraint-prop

        **sizeConstraint : SizeConstraint**

        This property holds the resize mode of the layout

        The default mode is **SetDefaultConstraint** .

        **Access functions:**

        QLayout::SizeConstraint **sizeConstraint** () const
        void
        **setSizeConstraint** (QLayout::SizeConstraint)
        """
        ...

    @typing.overload
    def setAlignment(self, w: QWidget, alignment: QtCore.Qt.AlignmentFlag) -> bool:
        """
        https://doc.qt.io/qt-6/qlayout.html#setAlignment

        **bool QLayout::setAlignment(QWidget * w , Qt::Alignment alignment )**

        Sets the alignment for widget **w** to **alignment** and returns true if
        **w** is found in this layout (not including child layouts); otherwise
        returns `false`.
        """
        ...

    @typing.overload
    def setAlignment(self, l: "QLayout", alignment: QtCore.Qt.AlignmentFlag) -> bool:
        """
        https://doc.qt.io/qt-6/qlayout.html#setAlignment-1

        **bool QLayout::setAlignment(QLayout * l , Qt::Alignment alignment )**

        This is an overloaded function.

        Sets the alignment for the layout **l** to **alignment** and returns
        `true` if **l** is found in this layout (not including child layouts);
        otherwise returns `false`.
        """
        ...

    @typing.overload
    def setAlignment(self, a0: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#setAlignment

        **bool QLayout::setAlignment(QWidget * w , Qt::Alignment alignment )**

        Sets the alignment for widget **w** to **alignment** and returns true if
        **w** is found in this layout (not including child layouts); otherwise
        returns `false`.
        """
        ...

    def setSpacing(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qlayout.html#spacing-prop

        **spacing : int**

        This property holds the spacing between widgets inside the layout

        If no value is explicitly set, the layout's spacing is inherited from
        the parent layout, or from the style settings for the parent widget.

        For **QGridLayout**  and **QFormLayout** , it is possible to set
        different horizontal and vertical spacings using
        **setHorizontalSpacing** () and **setVerticalSpacing** (). In that case,
        spacing() returns -1.

        **Access functions:**

        virtual int **spacing** () const
        virtual void **setSpacing** (int)

        **See also** **contentsRect** (), **getContentsMargins** (),
        **QStyle::layoutSpacing** (), and **QStyle::pixelMetric** ().

        **Member Function Documentation**
        """
        ...

    def spacing(self) -> int:
        """
        https://doc.qt.io/qt-6/qlayout.html#spacing-prop

        **spacing : int**

        This property holds the spacing between widgets inside the layout

        If no value is explicitly set, the layout's spacing is inherited from
        the parent layout, or from the style settings for the parent widget.

        For **QGridLayout**  and **QFormLayout** , it is possible to set
        different horizontal and vertical spacings using
        **setHorizontalSpacing** () and **setVerticalSpacing** (). In that case,
        spacing() returns -1.

        **Access functions:**

        virtual int **spacing** () const
        virtual void **setSpacing** (int)

        **See also** **contentsRect** (), **getContentsMargins** (),
        **QStyle::layoutSpacing** (), and **QStyle::pixelMetric** ().

        **Member Function Documentation**
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QCollator(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcollator.html

    **Detailed Description**

    QCollator is initialized with a **QLocale** . It can then be used to compare
    and sort strings in using the ordering appropriate to the locale.

    A QCollator object can be used together with template-based sorting
    algorithms, such as std::sort(), to sort a list with **QString**  entries.

    **QStringList**  sortedStrings(**QStringList**  seq)
        {
    **QCollator**  order;
            std::sort(seq.begin(), seq.end(), order);
    return seq;
        }

    In addition to the locale, several optional flags can be set that influence
    the result of the collation.

    **Note:** On Linux, Qt is normally compiled to use ICU. When it isn't, all
    options are ignored and the only supported locales are the system default
    (that `setlocale(LC_COLLATE, nullptr)` would report) and the "C" locale.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcollator.html#QCollator

        **[since 5.13] QCollator::QCollator()**

        Constructs a QCollator using the default locale's collation locale.

        The system locale, when used as default locale, may have a collation
        locale other than itself (e.g. on Unix, if LC_COLLATE is set differently
        to LANG in the environment). All other locales are their own collation
        locales.

        This function was introduced in Qt 5.13.

        **See also** **setLocale** (), **QLocale::collation** (), and
        **QLocale::setDefault** ().
        """
        ...

    @typing.overload
    def __init__(self, locale: "QLocale") -> None:
        """
        https://doc.qt.io/qt-6/qcollator.html#QCollator-1

        **QCollator::QCollator(const QLocale & locale )**

        Constructs a QCollator using the given **locale**.

        **See also** **setLocale** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QCollator") -> None:
        """
        https://doc.qt.io/qt-6/qcollator.html#QCollator-2

        **QCollator::QCollator(const QCollator & other )**

        Creates a copy of **other**.
        """
        ...

    def sortKey(self, string: str) -> QCollatorSortKey:
        """
        https://doc.qt.io/qt-6/qcollator.html#sortKey

        **QCollatorSortKey QCollator::sortKey(const QString & string ) const**

        Returns a sortKey for **string**.

        Creating the sort key is usually somewhat slower, than using the
        **compare** () methods directly. But if the string is compared
        repeatedly (e.g. when sorting a whole list of strings), it's usually
        faster to create the sort keys for each string and then sort using the
        keys.

        **Note:** Not supported with the C (a.k.a. POSIX) locale on Darwin.
        """
        ...

    def compare(self, s1: str, s2: str) -> int:
        """
        https://doc.qt.io/qt-6/qcollator.html#compare

        **[since 5.13] int QCollator::compare(QStringView s1 , QStringView s2 )
        const**

        Compares **s1** with **s2**.

        Returns an integer less than, equal to, or greater than zero depending
        on whether **s1** sorts before, with or after **s2**.

        This function was introduced in Qt 5.13.
        """
        ...

    def ignorePunctuation(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcollator.html#ignorePunctuation

        **bool QCollator::ignorePunctuation() const**

        Returns whether punctuation and symbols are ignored when collating.

        When `true`, strings are compared as if all punctuation and symbols were
        removed from each string.

        **See also** **setIgnorePunctuation** ().
        """
        ...

    def setIgnorePunctuation(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcollator.html#setIgnorePunctuation

        **void QCollator::setIgnorePunctuation(bool on )**

        Ignores punctuation and symbols if **on** is `true`, attends to them if
        `false`.

        **See also** **ignorePunctuation** ().
        """
        ...

    def numericMode(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcollator.html#numericMode

        **bool QCollator::numericMode() const**

        Returns `true` if numeric sorting is enabled, `false` otherwise.

        When `true`, numerals are recognized as numbers and sorted in arithmetic
        order; for example, 100 sortes after 99. When `false`, numbers are
        sorted in lexical order, so that 100 sorts before 99 (because 1 is
        before 9). By default, this option is disabled.

        **See also** **setNumericMode** ().
        """
        ...

    def setNumericMode(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcollator.html#setNumericMode

        **void QCollator::setNumericMode(bool on )**

        Enables numeric sorting mode when **on** is `true`.

        **See also** **numericMode** ().
        """
        ...

    def setCaseSensitivity(self, cs: Qt.CaseSensitivity) -> None:
        """
        https://doc.qt.io/qt-6/qcollator.html#setCaseSensitivity

        **void QCollator::setCaseSensitivity(Qt::CaseSensitivity cs )**

        Sets the case-sensitivity of the collator to **cs**.

        **See also** **caseSensitivity** ().
        """
        ...

    def caseSensitivity(self) -> Qt.CaseSensitivity:
        """
        https://doc.qt.io/qt-6/qcollator.html#caseSensitivity

        **Qt::CaseSensitivity QCollator::caseSensitivity() const**

        Returns case sensitivity of the collator.

        This defaults to case-sensitive until set.

        **Note:** In the C locale, when case-sensitive, all lower-case letters
        sort after all upper-case letters, where most locales sort each lower-
        case letter either immediately before or immediately after its upper-
        case partner. Thus "Zap" sorts before "ape" in the C locale but after in
        most others.

        **See also** **setCaseSensitivity** ().
        """
        ...

    def locale(self) -> "QLocale":
        """
        https://doc.qt.io/qt-6/qcollator.html#locale

        **QLocale QCollator::locale() const**

        Returns the locale of the collator.

        Unless supplied to the constructor or by calling **setLocale** (), the
        system's default collation locale is used.

        **See also** **setLocale** () and **QLocale::collation** ().
        """
        ...

    def setLocale(self, locale: "QLocale") -> None:
        """
        https://doc.qt.io/qt-6/qcollator.html#setLocale

        **void QCollator::setLocale(const QLocale & locale )**

        Sets the locale of the collator to **locale**.

        **See also** **locale** ().
        """
        ...

    def swap(self, other: "QCollator") -> None:
        """
        https://doc.qt.io/qt-6/qcollator.html#swap

        **void QCollator::swap(QCollator & other )**

        Swaps this collator with **other**. This function is very fast and never
        fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QUrl(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qurl.html

    **Detailed Description**

    It can parse and construct URLs in both encoded and unencoded form. QUrl
    also has support for internationalized domain names (IDNs).

    The most common way to use QUrl is to initialize it via the constructor by
    passing a **QString** . Otherwise, **setUrl** () can also be used.

    URLs can be represented in two forms: encoded or unencoded. The unencoded
    representation is suitable for showing to users, but the encoded
    representation is typically what you would send to a web server. For
    example, the unencoded URL "http://bühler.example.com/List of
    applicants.xml" would be sent to the server as "http://xn--bhler-
    kva.example.com/List%20of%20applicants.xml".

    A URL can also be constructed piece by piece by calling **setScheme** (),
    **setUserName** (), **setPassword** (), **setHost** (), **setPort** (),
    **setPath** (), **setQuery** () and **setFragment** (). Some convenience
    functions are also available: **setAuthority** () sets the user name,
    password, host and port. **setUserInfo** () sets the user name and password
    at once.

    Call **isValid** () to check if the URL is valid. This can be done at any
    point during the constructing of a URL. If **isValid** () returns `false`,
    you should **clear** () the URL before proceeding, or start over by parsing
    a new URL with **setUrl** ().

    Constructing a query is particularly convenient through the use of the
    **QUrlQuery**  class and its methods **QUrlQuery::setQueryItems** (),
    **QUrlQuery::addQueryItem** () and **QUrlQuery::removeQueryItem** (). Use
    **QUrlQuery::setQueryDelimiters** () to customize the delimiters used for
    generating the query string.

    For the convenience of generating encoded URL strings or query strings,
    there are two static functions called **fromPercentEncoding** () and
    **toPercentEncoding** () which deal with percent encoding and decoding of
    **QString**  objects.

    **fromLocalFile** () constructs a QUrl by parsing a local file path.
    **toLocalFile** () converts a URL to a local file path.

    The human readable representation of the URL is fetched with **toString**
    (). This representation is appropriate for displaying a URL to a user in
    unencoded form. The encoded form however, as returned by **toEncoded** (),
    is for internal use, passing to web servers, mail clients and so on. Both
    forms are technically correct and represent the same URL unambiguously -- in
    fact, passing either form to QUrl's constructor or to **setUrl** () will
    yield the same QUrl object.

    QUrl conforms to the URI specification from **RFC 3986**  (Uniform Resource
    Identifier: Generic Syntax), and includes scheme extensions from **RFC
    1738**  (Uniform Resource Locators). Case folding rules in QUrl conform to
    **RFC 3491**  (Nameprep: A Stringprep Profile for Internationalized Domain
    Names (IDN)). It is also compatible with the **file URI specification**
    from freedesktop.org, provided that the locale encodes file names using
    UTF-8 (required by IDN).

    **Relative URLs vs Relative Paths**

    Calling **isRelative** () will return whether or not the URL is relative. A
    relative URL has no **scheme** . For example:

    **qDebug** () << **QUrl** ("main.qml").isRelative();          // true: no
    scheme
            **qDebug** () << **QUrl** ("qml/main.qml").isRelative();
    // true: no scheme
            **qDebug** () << **QUrl**
    ("file:main.qml").isRelative();     // false: has "file" scheme
    **qDebug** () << **QUrl** ("file:qml/main.qml").isRelative(); // false: has
    "file" scheme

    Notice that a URL can be absolute while containing a relative path, and vice
    versa:

    // Absolute URL, relative path
            **QUrl**  url("file:file.txt");
    **qDebug** () << url.isRelative();                 // false: has "file"
    scheme
            **qDebug** () << **QDir** ::isAbsolutePath(url.path()); //
    false: relative path

            // Relative URL, absolute path
            url
    = **QUrl** ("/home/user/file.txt");
            **qDebug** () <<
    url.isRelative();                 // true: has no scheme
            **qDebug**
    () << **QDir** ::isAbsolutePath(url.path()); // true: absolute path

    A relative URL can be resolved by passing it as an argument to **resolved**
    (), which returns an absolute URL. **isParentOf** () is used for determining
    whether one URL is a parent of another.

    **Error checking**

    QUrl is capable of detecting many errors in URLs while parsing it or when
    components of the URL are set with individual setter methods (like
    **setScheme** (), **setHost** () or **setPath** ()). If the parsing or
    setter function is successful, any previously recorded error conditions will
    be discarded.

    By default, QUrl setter methods operate in **QUrl::TolerantMode** , which
    means they accept some common mistakes and mis-representation of data. An
    alternate method of parsing is **QUrl::StrictMode** , which applies further
    checks. See **QUrl::ParsingMode**  for a description of the difference of
    the parsing modes.

    QUrl only checks for conformance with the URL specification. It does not try
    to verify that high-level protocol URLs are in the format they are expected
    to be by handlers elsewhere. For example, the following URIs are all
    considered valid by QUrl, even if they do not make sense when used:

    * "http:/filename.html"
      * "mailto://example.com"

    When the parser encounters an error, it signals the event by making
    **isValid** () return false and **toString** () / **toEncoded** () return an
    empty string. If it is necessary to show the user the reason why the URL
    failed to parse, the error condition can be obtained from QUrl by calling
    **errorString** (). Note that this message is highly technical and may not
    make sense to end-users.

    QUrl is capable of recording only one error condition. If more than one
    error is found, it is undefined which error is reported.

    **Character Conversions**

    Follow these rules to avoid erroneous character conversion when dealing with
    URLs and strings:

    * When creating a **QString**  to contain a URL from a **QByteArray**  or a
    char*, always use **QString::fromUtf8** ().
    """

    class UserInputResolutionOption(enum.Flag):
        DefaultResolution: QUrl = ...
        AssumeLocalFile: QUrl = ...

    class ComponentFormattingOption(enum.IntFlag):
        PrettyDecoded: QUrl = ...
        EncodeSpaces: QUrl = ...
        EncodeUnicode: QUrl = ...
        EncodeDelimiters: QUrl = ...
        EncodeReserved: QUrl = ...
        DecodeReserved: QUrl = ...
        FullyEncoded: QUrl = ...
        FullyDecoded: QUrl = ...

    class UrlFormattingOption(enum.IntFlag):
        None_: QUrl = ...
        RemoveScheme: QUrl = ...
        RemovePassword: QUrl = ...
        RemoveUserInfo: QUrl = ...
        RemovePort: QUrl = ...
        RemoveAuthority: QUrl = ...
        RemovePath: QUrl = ...
        RemoveQuery: QUrl = ...
        RemoveFragment: QUrl = ...
        PreferLocalFile: QUrl = ...
        StripTrailingSlash: QUrl = ...
        RemoveFilename: QUrl = ...
        NormalizePathSegments: QUrl = ...

    class ParsingMode(enum.Enum):
        TolerantMode: QUrl = ...
        StrictMode: QUrl = ...
        DecodedMode: QUrl = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#QUrl

        **QUrl::QUrl()**

        Constructs an empty QUrl object.
        """
        ...

    @typing.overload
    def __init__(self, url: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#QUrl-1

        **QUrl::QUrl(const QUrl & other )**

        Constructs a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, copy: "QUrl") -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#QUrl-2

        **QUrl::QUrl(const QString & url , QUrl::ParsingMode parsingMode =
        TolerantMode)**

        Constructs a URL by parsing **url**. QUrl will automatically percent
        encode all characters that are not allowed in a URL and decode the
        percent-encoded sequences that represent an unreserved character
        (letters, digits, hyphens, underscores, dots and tildes). All other
        characters are left in their original forms.

        Parses the **url** using the parser mode **parsingMode**. In
        **TolerantMode**  (the default), QUrl will correct certain mistakes,
        notably the presence of a percent character ('%') not followed by two
        hexadecimal digits, and it will accept any character in any position. In
        **StrictMode** , encoding mistakes will not be tolerated and QUrl will
        also check that certain forbidden characters are not present in
        unencoded form. If an error is detected in **StrictMode** , **isValid**
        () will return false. The parsing mode **DecodedMode**  is not permitted
        in this context.

        Example:

        **QUrl**  url("http://www.example.com/List of holidays.xml");
            //
        url.toEncoded() == "http://www.example.com/List%20of%20holidays.xml"

        To construct a URL from an encoded string, you can also use
        **fromEncoded** ():

        **QUrl**  url = **QUrl** ::fromEncoded("http://qt-
        project.org/List%20of%20holidays.xml");

        Both functions are equivalent and, in Qt 5, both functions accept
        encoded data. Usually, the choice of the QUrl constructor or **setUrl**
        () versus **fromEncoded** () will depend on the source data: the
        constructor and **setUrl** () take a **QString** , whereas
        **fromEncoded**  takes a **QByteArray** .

        **See also** **setUrl** (), **fromEncoded** (), and **TolerantMode** .
        """
        ...

    def matches(self, url: "QUrl", options: "QUrl.UrlFormattingOption") -> bool:
        """
        https://doc.qt.io/qt-6/qurl.html#matches

        **[since 5.2] bool QUrl::matches(const QUrl & url ,
        QUrl::FormattingOptions options ) const**

        Returns `true` if this URL and the given **url** are equal after
        applying **options** to both; otherwise returns `false`.

        This is equivalent to calling adjusted(options) on both URLs and
        comparing the resulting urls, but faster.

        This function was introduced in Qt 5.2.
        """
        ...

    def fileName(self, options: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#fileName

        **[since 5.2] QString QUrl::fileName(QUrl::ComponentFormattingOptions
        options = FullyDecoded) const**

        Returns the name of the file, excluding the directory path.

        Note that, if this **QUrl**  object is given a path ending in a slash,
        the name of the file is considered empty.

        If the path doesn't contain any slash, it is fully returned as the
        fileName.

        Example:

        **QUrl**  url("http://qt-project.org/support/file.html");
            //
        url.adjusted(RemoveFilename) == "http://qt-project.org/support/"
            //
        url.fileName() == "file.html"

        The **options** argument controls how to format the file name component.
        All values produce an unambiguous result. With **QUrl::FullyDecoded** ,
        all percent-encoded sequences are decoded; otherwise, the returned value
        may contain some percent-encoded sequences for some control sequences
        not representable in decoded form in **QString** .

        This function was introduced in Qt 5.2.

        **See also** **path** ().
        """
        ...

    def adjusted(self, options: "QUrl.UrlFormattingOption") -> "QUrl":
        """
        https://doc.qt.io/qt-6/qurl.html#adjusted

        **[since 5.2] QUrl QUrl::adjusted(QUrl::FormattingOptions options )
        const**

        Returns an adjusted version of the URL. The output can be customized by
        passing flags with **options**.

        The encoding options from **QUrl::ComponentFormattingOption**  don't
        make much sense for this method, nor does **QUrl::PreferLocalFile** .

        This is always equivalent to **QUrl** (url.**toString** (options)).

        This function was introduced in Qt 5.2.

        **See also** **FormattingOptions** , **toEncoded** (), and **toString**
        ().
        """
        ...

    @staticmethod
    def fromStringList(
        uris: typing.Iterable[str], mode: "QUrl.ParsingMode" = ...
    ) -> typing.List["QUrl"]:
        """
        https://doc.qt.io/qt-6/qurl.html#fromStringList

        **[static, since 5.1] QList<QUrl> QUrl::fromStringList(const QStringList
        & urls , QUrl::ParsingMode mode = TolerantMode)**

        Converts a list of strings representing **urls** into a list of urls,
        using **QUrl** (str, **mode** ). Note that this means all strings must
        be urls, not for instance local paths.

        This function was introduced in Qt 5.1.
        """
        ...

    @staticmethod
    def toStringList(
        uris: typing.Iterable["QUrl"], options: "QUrl.UrlFormattingOption" = ...
    ) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qurl.html#toStringList

        **[static, since 5.1] QStringList QUrl::toStringList(const QList<QUrl> &
        urls , QUrl::FormattingOptions options =
        FormattingOptions(PrettyDecoded))**

        Converts a list of **urls** into a list of **QString**  objects, using
        **toString** ( **options** ).

        This function was introduced in Qt 5.1.
        """
        ...

    def query(self, options: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#query

        **QString QUrl::query(QUrl::ComponentFormattingOptions options =
        PrettyDecoded) const**

        Returns the query string of the URL if there's a query string, or an
        empty result if not. To determine if the parsed URL contained a query
        string, use **hasQuery** ().

        The **options** argument controls how to format the query component. All
        values produce an unambiguous result. With **QUrl::FullyDecoded** , all
        percent-encoded sequences are decoded; otherwise, the returned value may
        contain some percent-encoded sequences for some control sequences not
        representable in decoded form in **QString** .

        Note that use of **QUrl::FullyDecoded**  in queries is discouraged, as
        queries often contain data that is supposed to remain percent-encoded,
        including the use of the "%2B" sequence to represent a plus character
        ('+').

        **See also** **setQuery** () and **hasQuery** ().
        """
        ...

    @typing.overload
    def setQuery(self, query: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setQuery

        **void QUrl::setQuery(const QString & query , QUrl::ParsingMode mode =
        TolerantMode)**

        Sets the query string of the URL to **query**.

        This function is useful if you need to pass a query string that does not
        fit into the key-value pattern, or that uses a different scheme for
        encoding special characters than what is suggested by **QUrl** .

        Passing a value of QString() to **query** (a null **QString** ) unsets
        the query completely. However, passing a value of **QString** ("") will
        set the query to an empty value, as if the original URL had a lone "?".

        The **query** data is interpreted according to **mode** : in
        **StrictMode** , any '%' characters must be followed by exactly two
        hexadecimal characters and some characters (including space) are not
        allowed in undecoded form. In **TolerantMode** , all characters are
        accepted in undecoded form and the tolerant parser will correct stray
        '%' not followed by two hex characters. In **DecodedMode** , '%' stand
        for themselves and encoded characters are not possible.

        Query strings often contain percent-encoded sequences, so use of
        **DecodedMode**  is discouraged. One special sequence to be aware of is
        that of the plus character ('+'). **QUrl**  does not convert spaces to
        plus characters, even though HTML forms posted by web browsers do. In
        order to represent an actual plus character in a query, the sequence
        "%2B" is usually used. This function will leave "%2B" sequences
        untouched in **TolerantMode**  or **StrictMode** .

        **See also** **query** () and **hasQuery** ().
        """
        ...

    @typing.overload
    def setQuery(self, query: "QUrlQuery") -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setQuery-1

        **[since 5.0] void QUrl::setQuery(const QUrlQuery & query )**

        This is an overloaded function.

        Sets the query string of the URL to **query**.

        This function reconstructs the query string from the **QUrlQuery**
        object and sets on this **QUrl**  object. This function does not have
        parsing parameters because the **QUrlQuery**  contains data that is
        already parsed.

        This function was introduced in Qt 5.0.

        **See also** **query** () and **hasQuery** ().
        """
        ...

    @typing.overload
    def toDisplayString(self, options: "QUrl.UrlFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#toDisplayString

        **[since 5.0] QString QUrl::toDisplayString(QUrl::FormattingOptions
        options = FormattingOptions(PrettyDecoded)) const**

        Returns a human-displayable string representation of the URL. The output
        can be customized by passing flags with **options**. The option
        **RemovePassword**  is always enabled, since passwords should never be
        shown back to users.

        With the default options, the resulting **QString**  can be passed back
        to a **QUrl**  later on, but any password that was present initially
        will be lost.

        This function was introduced in Qt 5.0.

        **See also** **FormattingOptions** , **toEncoded** (), and **toString**
        ().
        """
        ...

    @typing.overload
    def toDisplayString(self, options: "QUrl.ComponentFormattingOption") -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#toDisplayString

        **[since 5.0] QString QUrl::toDisplayString(QUrl::FormattingOptions
        options = FormattingOptions(PrettyDecoded)) const**

        Returns a human-displayable string representation of the URL. The output
        can be customized by passing flags with **options**. The option
        **RemovePassword**  is always enabled, since passwords should never be
        shown back to users.

        With the default options, the resulting **QString**  can be passed back
        to a **QUrl**  later on, but any password that was present initially
        will be lost.

        This function was introduced in Qt 5.0.

        **See also** **FormattingOptions** , **toEncoded** (), and **toString**
        ().
        """
        ...

    def isLocalFile(self) -> bool:
        """
        https://doc.qt.io/qt-6/qurl.html#isLocalFile

        **bool QUrl::isLocalFile() const**

        Returns `true` if this URL is pointing to a local file path. A URL is a
        local file path if the scheme is "file".

        Note that this function considers URLs with hostnames to be local file
        paths, even if the eventual file path cannot be opened with
        **QFile::open** ().

        **See also** **fromLocalFile** () and **toLocalFile** ().
        """
        ...

    def swap(self, other: "QUrl") -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#swap

        **void QUrl::swap(QUrl & other )**

        Swaps URL **other** with this URL. This operation is very fast and never
        fails.
        """
        ...

    @staticmethod
    def fromUserInput(
        userInput: str,
        workingDirectory: str = ...,
        options: "QUrl.UserInputResolutionOption" = ...,
    ) -> "QUrl":
        """
        https://doc.qt.io/qt-6/qurl.html#fromUserInput

        **[static, since 5.4] QUrl QUrl::fromUserInput(const QString & userInput
        , const QString & workingDirectory = QString(),
        QUrl::UserInputResolutionOptions options = DefaultResolution)**

        Returns a valid URL from a user supplied **userInput** string if one can
        be deduced. In the case that is not possible, an invalid **QUrl** () is
        returned.

        This allows the user to input a URL or a local file path in the form of
        a plain string. This string can be manually typed into a location bar,
        obtained from the clipboard, or passed in via command line arguments.

        When the string is not already a valid URL, a best guess is performed,
        making various assumptions.

        In the case the string corresponds to a valid file path on the system, a
        file:// URL is constructed, using **QUrl::fromLocalFile** ().

        If that is not the case, an attempt is made to turn the string into a
        http:// or ftp:// URL. The latter in the case the string starts with
        'ftp'. The result is then passed through **QUrl** 's tolerant parser,
        and in the case or success, a valid **QUrl**  is returned, or else a
        **QUrl** ().

        **Examples:**

        * qt-project.org becomes http://qt-project.org
          * ftp.qt-project.org
        becomes ftp://ftp.qt-project.org
          * hostname becomes http://hostname
        * /home/user/test.html becomes file:///home/user/test.html

        In order to be able to handle relative paths, this method takes an
        optional **workingDirectory** path. This is especially useful when
        handling command line arguments. If **workingDirectory** is empty, no
        handling of relative paths will be done.

        By default, an input string that looks like a relative path will only be
        treated as such if the file actually exists in the given working
        directory. If the application can handle files that don't exist yet, it
        should pass the flag **AssumeLocalFile**  in **options**.

        This function was introduced in Qt 5.4.
        """
        ...

    @staticmethod
    def setIdnWhitelist(a0: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setIdnWhitelist

        **[static] void QUrl::setIdnWhitelist(const QStringList & list )**

        Sets the whitelist of Top-Level Domains (TLDs) that are allowed to have
        non-ASCII characters in domains to the value of **list**.

        Note that if you call this function, you need to do so **before** you
        start any threads that might access **idnWhitelist** ().

        Qt comes with a default list that contains the Internet top-level
        domains that have published support for Internationalized Domain Names
        (IDNs) and rules to guarantee that no deception can happen between
        similarly-looking characters (such as the Latin lowercase letter `'a'`
        and the Cyrillic equivalent, which in most fonts are visually
        identical).

        This list is periodically maintained, as registrars publish new rules.

        This function is provided for those who need to manipulate the list, in
        order to add or remove a TLD. It is not recommended to change its value
        for purposes other than testing, as it may expose users to security
        risks.

        **See also** **idnWhitelist** ().
        """
        ...

    @staticmethod
    def idnWhitelist() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qurl.html#idnWhitelist

        **[static] QStringList QUrl::idnWhitelist()**

        Returns the current whitelist of top-level domains that are allowed to
        have non-ASCII characters in their compositions.

        See **setIdnWhitelist** () for the rationale of this list.

        **See also** **setIdnWhitelist** ().
        """
        ...

    @staticmethod
    def toAce(a0: str) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qurl.html#toAce

        **[static] QByteArray QUrl::toAce(const QString & domain )**

        Returns the ASCII Compatible Encoding of the given domain name
        **domain**. The result of this function is considered equivalent to
        **domain**.

        The ASCII-Compatible Encoding (ACE) is defined by RFC 3490, RFC 3491 and
        RFC 3492. It is part of the Internationalizing Domain Names in
        Applications (IDNA) specification, which allows for domain names (like
        `"example.com"`) to be written using international characters.

        This function returns an empty **QByteArray**  if **domain** is not a
        valid hostname. Note, in particular, that IPv6 literals are not valid
        domain names.
        """
        ...

    @staticmethod
    def fromAce(a0: QByteArray) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#fromAce

        **[static] QString QUrl::fromAce(const QByteArray & domain )**

        Returns the Unicode form of the given domain name **domain** , which is
        encoded in the ASCII Compatible Encoding (ACE). The result of this
        function is considered equivalent to **domain**.

        If the value in **domain** cannot be encoded, it will be converted to
        **QString**  and returned.

        The ASCII Compatible Encoding (ACE) is defined by RFC 3490, RFC 3491 and
        RFC 3492. It is part of the Internationalizing Domain Names in
        Applications (IDNA) specification, which allows for domain names (like
        `"example.com"`) to be written using international characters.
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#errorString

        **QString QUrl::errorString() const**

        Returns an error message if the last operation that modified this
        **QUrl**  object ran into a parsing error. If no error was detected,
        this function returns an empty string and **isValid** () returns `true`.

        The error message returned by this function is technical in nature and
        may not be understood by end users. It is mostly useful to developers
        trying to understand why **QUrl**  will not accept some input.

        **See also** **QUrl::ParsingMode** .
        """
        ...

    def hasFragment(self) -> bool:
        """
        https://doc.qt.io/qt-6/qurl.html#hasFragment

        **bool QUrl::hasFragment() const**

        Returns `true` if this URL contains a fragment (i.e., if # was seen on
        it).

        **See also** **fragment** () and **setFragment** ().
        """
        ...

    def hasQuery(self) -> bool:
        """
        https://doc.qt.io/qt-6/qurl.html#hasQuery

        **bool QUrl::hasQuery() const**

        Returns `true` if this URL contains a Query (i.e., if ? was seen on it).

        **See also** **setQuery** (), **query** (), and **hasFragment** ().
        """
        ...

    @staticmethod
    def toPercentEncoding(
        input: str, exclude: QByteArray = ..., include: QByteArray = ...
    ) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qurl.html#toPercentEncoding

        **[static] QByteArray QUrl::toPercentEncoding(const QString & input ,
        const QByteArray & exclude = QByteArray(), const QByteArray & include =
        QByteArray())**

        Returns an encoded copy of **input**. **input** is first converted to
        UTF-8, and all ASCII-characters that are not in the unreserved group are
        percent encoded. To prevent characters from being percent encoded pass
        them to **exclude**. To force characters to be percent encoded pass them
        to **include**.

        Unreserved is defined as: `ALPHA / DIGIT / "-" / "." / "_" / "~"`

        **QByteArray**  ba = **QUrl** ::toPercentEncoding("{a fishy string?}",
        "{}", "s");
            **qDebug** (ba.constData());
            // prints "{a fi%73hy
        %73tring%3F}"
        """
        ...

    @staticmethod
    def fromPercentEncoding(a0: QByteArray) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#fromPercentEncoding

        **[static] QString QUrl::fromPercentEncoding(const QByteArray & input
        )**

        Returns a decoded copy of **input**. **input** is first decoded from
        percent encoding, then converted from UTF-8 to unicode.

        **Note:** Given invalid input (such as a string containing the sequence
        "%G5", which is not a valid hexadecimal number) the output will be
        invalid as well. As an example: the sequence "%G5" could be decoded to
        'W'.
        """
        ...

    def isDetached(self) -> bool:
        ...

    def detach(self) -> None:
        ...

    @staticmethod
    def fromEncoded(u: QByteArray, mode: "QUrl.ParsingMode" = ...) -> "QUrl":
        """
        https://doc.qt.io/qt-6/qurl.html#fromEncoded

        **[static] QUrl QUrl::fromEncoded(const QByteArray & input ,
        QUrl::ParsingMode parsingMode = TolerantMode)**

        Parses **input** and returns the corresponding **QUrl** . **input** is
        assumed to be in encoded form, containing only ASCII characters.

        Parses the URL using **parsingMode**. See **setUrl** () for more
        information on this parameter. **QUrl::DecodedMode**  is not permitted
        in this context.

        **See also** **toEncoded** () and **setUrl** ().
        """
        ...

    @typing.overload
    def toEncoded(self, options: "QUrl.UrlFormattingOption" = ...) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qurl.html#toEncoded

        **QByteArray QUrl::toEncoded(QUrl::FormattingOptions options =
        FullyEncoded) const**

        Returns the encoded representation of the URL if it's valid; otherwise
        an empty **QByteArray**  is returned. The output can be customized by
        passing flags with **options**.

        The user info, path and fragment are all converted to UTF-8, and all
        non-ASCII characters are then percent encoded. The host name is encoded
        using Punycode.
        """
        ...

    @typing.overload
    def toEncoded(self, options: "QUrl.ComponentFormattingOption") -> QByteArray:
        """
        https://doc.qt.io/qt-6/qurl.html#toEncoded

        **QByteArray QUrl::toEncoded(QUrl::FormattingOptions options =
        FullyEncoded) const**

        Returns the encoded representation of the URL if it's valid; otherwise
        an empty **QByteArray**  is returned. The output can be customized by
        passing flags with **options**.

        The user info, path and fragment are all converted to UTF-8, and all
        non-ASCII characters are then percent encoded. The host name is encoded
        using Punycode.
        """
        ...

    @typing.overload
    def toString(self, options: "QUrl.UrlFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#toString

        **QString QUrl::toString(QUrl::FormattingOptions options =
        FormattingOptions(PrettyDecoded)) const**

        Returns a string representation of the URL. The output can be customized
        by passing flags with **options**. The option **QUrl::FullyDecoded**  is
        not permitted in this function since it would generate ambiguous data.

        The default formatting option is **PrettyDecoded** .

        **See also** **FormattingOptions** , **url** (), and **setUrl** ().
        """
        ...

    @typing.overload
    def toString(self, options: "QUrl.ComponentFormattingOption") -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#toString

        **QString QUrl::toString(QUrl::FormattingOptions options =
        FormattingOptions(PrettyDecoded)) const**

        Returns a string representation of the URL. The output can be customized
        by passing flags with **options**. The option **QUrl::FullyDecoded**  is
        not permitted in this function since it would generate ambiguous data.

        The default formatting option is **PrettyDecoded** .

        **See also** **FormattingOptions** , **url** (), and **setUrl** ().
        """
        ...

    def toLocalFile(self) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#toLocalFile

        **QString QUrl::toLocalFile() const**

        Returns the path of this URL formatted as a local file path. The path
        returned will use forward slashes, even if it was originally created
        from one with backslashes.

        If this URL contains a non-empty hostname, it will be encoded in the
        returned value in the form found on SMB networks (for example,
        "//servername/path/to/file.txt").

        **qDebug** () << **QUrl** ("file:file.txt").toLocalFile();            //
        "file.txt"
                **qDebug** () << **QUrl**
        ("file:/home/user/file.txt").toLocalFile(); // "/home/user/file.txt"
        **qDebug** () << **QUrl** ("file.txt").toLocalFile();                 //
        ""; wasn't a local file as it had no scheme

        Note: if the path component of this URL contains a non-UTF-8 binary
        sequence (such as %80), the behaviour of this function is undefined.

        **See also** **fromLocalFile** () and **isLocalFile** ().
        """
        ...

    @staticmethod
    def fromLocalFile(localfile: str) -> "QUrl":
        """
        https://doc.qt.io/qt-6/qurl.html#fromLocalFile

        **[static] QUrl QUrl::fromLocalFile(const QString & localFile )**

        Returns a **QUrl**  representation of **localFile** , interpreted as a
        local file. This function accepts paths separated by slashes as well as
        the native separator for this platform.

        This function also accepts paths with a doubled leading slash (or
        backslash) to indicate a remote file, as in
        "//servername/path/to/file.txt". Note that only certain platforms can
        actually open this file using **QFile::open** ().

        An empty **localFile** leads to an empty URL (since Qt 5.4).

        **qDebug** () << **QUrl** ::fromLocalFile("file.txt");            //
        QUrl("file:file.txt")
                **qDebug** () << **QUrl**
        ::fromLocalFile("/home/user/file.txt"); //
        QUrl("file:///home/user/file.txt")
                **qDebug** () << **QUrl**
        ::fromLocalFile("file:file.txt");       // doesn't make sense; expects
        path, not url with scheme

        In the first line in snippet above, a file URL is constructed from a
        local, relative path. A file URL with a relative path only makes sense
        if there is a base URL to resolve it against. For example:

        **QUrl**  url = **QUrl** ::fromLocalFile("file.txt");
                **QUrl**
        baseUrl = **QUrl** ("file:/home/user/");
                // wrong: prints
        QUrl("file:file.txt"), as url already has a scheme
                **qDebug** ()
        << baseUrl.resolved(url);

        To resolve such a URL, it's necessary to remove the scheme beforehand:

        // correct: prints QUrl("file:///home/user/file.txt")
        url.setScheme(**QString** ());
                **qDebug** () <<
        baseUrl.resolved(url);

        For this reason, it is better to use a relative URL (that is, no scheme)
        for relative file paths:

        **QUrl**  url = **QUrl** ("file.txt");
                **QUrl**  baseUrl =
        **QUrl** ("file:/home/user/");
                // prints
        QUrl("file:///home/user/file.txt")
                **qDebug** () <<
        baseUrl.resolved(url);

        **See also** **toLocalFile** (), **isLocalFile** (), and
        **QDir::toNativeSeparators** ().
        """
        ...

    def isParentOf(self, url: "QUrl") -> bool:
        """
        https://doc.qt.io/qt-6/qurl.html#isParentOf

        **bool QUrl::isParentOf(const QUrl & childUrl ) const**

        Returns `true` if this URL is a parent of **childUrl**. **childUrl** is
        a child of this URL if the two URLs share the same scheme and authority,
        and this URL's path is a parent of the path of **childUrl**.
        """
        ...

    def isRelative(self) -> bool:
        """
        https://doc.qt.io/qt-6/qurl.html#isRelative

        **bool QUrl::isRelative() const**

        Returns `true` if the URL is relative; otherwise returns `false`. A URL
        is relative reference if its scheme is undefined; this function is
        therefore equivalent to calling **scheme** ().**isEmpty** ().

        Relative references are defined in RFC 3986 section 4.2.

        **See also** **Relative URLs vs Relative Paths** .
        """
        ...

    def resolved(self, relative: "QUrl") -> "QUrl":
        """
        https://doc.qt.io/qt-6/qurl.html#resolved

        **QUrl QUrl::resolved(const QUrl & relative ) const**

        Returns the result of the merge of this URL with **relative**. This URL
        is used as a base to convert **relative** to an absolute URL.

        If **relative** is not a relative URL, this function will return
        **relative** directly. Otherwise, the paths of the two URLs are merged,
        and the new URL returned has the scheme and authority of the base URL,
        but with the merged path, as in the following example:

        **QUrl**  baseUrl("http://qt.digia.com/Support/");
            **QUrl**
        relativeUrl("../Product/Library/");
            **qDebug**
        (baseUrl.resolved(relativeUrl).toString());
            // prints
        "http://qt.digia.com/Product/Library/"

        Calling resolved() with ".." returns a **QUrl**  whose directory is one
        level higher than the original. Similarly, calling resolved() with
        "../.." removes two levels from the path. If **relative** is "/", the
        path becomes "/".

        **See also** **isRelative** ().
        """
        ...

    def fragment(self, options: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#fragment

        **QString QUrl::fragment(QUrl::ComponentFormattingOptions options =
        PrettyDecoded) const**

        Returns the fragment of the URL. To determine if the parsed URL
        contained a fragment, use **hasFragment** ().

        The **options** argument controls how to format the fragment component.
        All values produce an unambiguous result. With **QUrl::FullyDecoded** ,
        all percent-encoded sequences are decoded; otherwise, the returned value
        may contain some percent-encoded sequences for some control sequences
        not representable in decoded form in **QString** .

        Note that **QUrl::FullyDecoded**  may cause data loss if those non-
        representable sequences are present. It is recommended to use that value
        when the result will be used in a non-URL context.

        **See also** **setFragment** () and **hasFragment** ().
        """
        ...

    def setFragment(self, fragment: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setFragment

        **void QUrl::setFragment(const QString & fragment , QUrl::ParsingMode
        mode = TolerantMode)**

        Sets the fragment of the URL to **fragment**. The fragment is the last
        part of the URL, represented by a '#' followed by a string of
        characters. It is typically used in HTTP for referring to a certain link
        or point on a page:

        ![](images/qurl-fragment.png)

        The fragment is sometimes also referred to as the URL "reference".

        Passing an argument of QString() (a null **QString** ) will unset the
        fragment. Passing an argument of **QString** ("") (an empty but not null
        **QString** ) will set the fragment to an empty string (as if the
        original URL had a lone "#").

        The **fragment** data is interpreted according to **mode** : in
        **StrictMode** , any '%' characters must be followed by exactly two
        hexadecimal characters and some characters (including space) are not
        allowed in undecoded form. In **TolerantMode** , all characters are
        accepted in undecoded form and the tolerant parser will correct stray
        '%' not followed by two hex characters. In **DecodedMode** , '%' stand
        for themselves and encoded characters are not possible.

        **QUrl::DecodedMode**  should be used when setting the fragment from a
        data source which is not a URL or with a fragment obtained by calling
        **fragment** () with the **QUrl::FullyDecoded**  formatting option.

        **See also** **fragment** () and **hasFragment** ().
        """
        ...

    def path(self, options: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#path

        **QString QUrl::path(QUrl::ComponentFormattingOptions options =
        FullyDecoded) const**

        Returns the path of the URL.

        **qDebug** () << **QUrl** ("file:file.txt").path();                   //
        "file.txt"
                **qDebug** () << **QUrl**
        ("/home/user/file.txt").path();             // "/home/user/file.txt"
        **qDebug** () << **QUrl** ("http://www.example.com/test/123").path(); //
        "/test/123"

        The **options** argument controls how to format the path component. All
        values produce an unambiguous result. With **QUrl::FullyDecoded** , all
        percent-encoded sequences are decoded; otherwise, the returned value may
        contain some percent-encoded sequences for some control sequences not
        representable in decoded form in **QString** .

        Note that **QUrl::FullyDecoded**  may cause data loss if those non-
        representable sequences are present. It is recommended to use that value
        when the result will be used in a non-URL context, such as sending to an
        FTP server.

        An example of data loss is when you have non-Unicode percent-encoded
        sequences and use **FullyDecoded**  (the default):

        **qDebug** () << **QUrl** ("/foo%FFbar").path();

        In this example, there will be some level of data loss because the `%FF`
        cannot be converted.

        Data loss can also occur when the path contains sub-delimiters (such as
        `+`):

        **qDebug** () << **QUrl** ("/foo+bar%2B").path(); // "/foo+bar+"

        Other decoding examples:

        const **QUrl**  url("/tmp/Mambo %235%3F.mp3");
                **qDebug** () <<
        url.path(**QUrl** ::FullyDecoded);  // "/tmp/Mambo #5?.mp3"
        **qDebug** () << url.path(**QUrl** ::PrettyDecoded); // "/tmp/Mambo
        #5?.mp3"
                **qDebug** () << url.path(**QUrl** ::FullyEncoded);  //
        "/tmp/Mambo%20%235%3F.mp3"

        **See also** **setPath** ().
        """
        ...

    def setPath(self, path: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setPath

        **void QUrl::setPath(const QString & path , QUrl::ParsingMode mode =
        DecodedMode)**

        Sets the path of the URL to **path**. The path is the part of the URL
        that comes after the authority but before the query string.

        ![](images/qurl-ftppath.png)

        For non-hierarchical schemes, the path will be everything following the
        scheme declaration, as in the following example:

        ![](images/qurl-mailtopath.png)

        The **path** data is interpreted according to **mode** : in
        **StrictMode** , any '%' characters must be followed by exactly two
        hexadecimal characters and some characters (including space) are not
        allowed in undecoded form. In **TolerantMode** , all characters are
        accepted in undecoded form and the tolerant parser will correct stray
        '%' not followed by two hex characters. In **DecodedMode** , '%' stand
        for themselves and encoded characters are not possible.

        **QUrl::DecodedMode**  should be used when setting the path from a data
        source which is not a URL, such as a dialog shown to the user or with a
        path obtained by calling **path** () with the **QUrl::FullyDecoded**
        formatting option.

        **See also** **path** ().
        """
        ...

    def port(self, defaultPort: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qurl.html#port

        **int QUrl::port(int defaultPort = -1) const**

        Returns the port of the URL, or **defaultPort** if the port is
        unspecified.

        Example:

        **QTcpSocket**  sock;
            sock.connectToHost(url.host(), url.port(80));

        **See also** **setPort** ().
        """
        ...

    def setPort(self, port: int) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setPort

        **void QUrl::setPort(int port )**

        Sets the port of the URL to **port**. The port is part of the authority
        of the URL, as described in **setAuthority** ().

        **port** must be between 0 and 65535 inclusive. Setting the port to -1
        indicates that the port is unspecified.

        **See also** **port** ().
        """
        ...

    def host(self, a0: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#host

        **QString QUrl::host(QUrl::ComponentFormattingOptions options =
        FullyDecoded) const**

        Returns the host of the URL if it is defined; otherwise an empty string
        is returned.

        The **options** argument controls how the hostname will be formatted.
        The **QUrl::EncodeUnicode**  option will cause this function to return
        the hostname in the ASCII-Compatible Encoding (ACE) form, which is
        suitable for use in channels that are not 8-bit clean or that require
        the legacy hostname (such as DNS requests or in HTTP request headers).
        If that flag is not present, this function returns the International
        Domain Name (IDN) in Unicode form, according to the list of permissible
        top-level domains (see **idnWhitelist** ()).

        All other flags are ignored. Host names cannot contain control or
        percent characters, so the returned value can be considered fully
        decoded.

        **See also** **setHost** (), **idnWhitelist** (), **setIdnWhitelist**
        (), and **authority** ().
        """
        ...

    def setHost(self, host: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setHost

        **void QUrl::setHost(const QString & host , QUrl::ParsingMode mode =
        DecodedMode)**

        Sets the host of the URL to **host**. The host is part of the authority.

        The **host** data is interpreted according to **mode** : in
        **StrictMode** , any '%' characters must be followed by exactly two
        hexadecimal characters and some characters (including space) are not
        allowed in undecoded form. In **TolerantMode** , all characters are
        accepted in undecoded form and the tolerant parser will correct stray
        '%' not followed by two hex characters. In **DecodedMode** , '%' stand
        for themselves and encoded characters are not possible.

        Note that, in all cases, the result of the parsing must be a valid
        hostname according to STD 3 rules, as modified by the Internationalized
        Resource Identifiers specification (RFC 3987). Invalid hostnames are not
        permitted and will cause **isValid** () to become false.

        **See also** **host** () and **setAuthority** ().
        """
        ...

    def password(self, options: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#password

        **QString QUrl::password(QUrl::ComponentFormattingOptions options =
        FullyDecoded) const**

        Returns the password of the URL if it is defined; otherwise an empty
        string is returned.

        The **options** argument controls how to format the user name component.
        All values produce an unambiguous result. With **QUrl::FullyDecoded** ,
        all percent-encoded sequences are decoded; otherwise, the returned value
        may contain some percent-encoded sequences for some control sequences
        not representable in decoded form in **QString** .

        Note that **QUrl::FullyDecoded**  may cause data loss if those non-
        representable sequences are present. It is recommended to use that value
        when the result will be used in a non-URL context, such as setting in
        **QAuthenticator**  or negotiating a login.

        **See also** **setPassword** ().
        """
        ...

    def setPassword(self, password: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setPassword

        **void QUrl::setPassword(const QString & password , QUrl::ParsingMode
        mode = DecodedMode)**

        Sets the URL's password to **password**. The **password** is part of the
        user info element in the authority of the URL, as described in
        **setUserInfo** ().

        The **password** data is interpreted according to **mode** : in
        **StrictMode** , any '%' characters must be followed by exactly two
        hexadecimal characters and some characters (including space) are not
        allowed in undecoded form. In **TolerantMode** , all characters are
        accepted in undecoded form and the tolerant parser will correct stray
        '%' not followed by two hex characters. In **DecodedMode** , '%' stand
        for themselves and encoded characters are not possible.

        **QUrl::DecodedMode**  should be used when setting the password from a
        data source which is not a URL, such as a password dialog shown to the
        user or with a password obtained by calling **password** () with the
        **QUrl::FullyDecoded**  formatting option.

        **See also** **password** () and **setUserInfo** ().
        """
        ...

    def userName(self, options: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#userName

        **QString QUrl::userName(QUrl::ComponentFormattingOptions options =
        FullyDecoded) const**

        Returns the user name of the URL if it is defined; otherwise an empty
        string is returned.

        The **options** argument controls how to format the user name component.
        All values produce an unambiguous result. With **QUrl::FullyDecoded** ,
        all percent-encoded sequences are decoded; otherwise, the returned value
        may contain some percent-encoded sequences for some control sequences
        not representable in decoded form in **QString** .

        Note that **QUrl::FullyDecoded**  may cause data loss if those non-
        representable sequences are present. It is recommended to use that value
        when the result will be used in a non-URL context, such as setting in
        **QAuthenticator**  or negotiating a login.

        **See also** **setUserName** () and **userInfo** ().
        """
        ...

    def setUserName(self, userName: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setUserName

        **void QUrl::setUserName(const QString & userName , QUrl::ParsingMode
        mode = DecodedMode)**

        Sets the URL's user name to **userName**. The **userName** is part of
        the user info element in the authority of the URL, as described in
        **setUserInfo** ().

        The **userName** data is interpreted according to **mode** : in
        **StrictMode** , any '%' characters must be followed by exactly two
        hexadecimal characters and some characters (including space) are not
        allowed in undecoded form. In **TolerantMode**  (the default), all
        characters are accepted in undecoded form and the tolerant parser will
        correct stray '%' not followed by two hex characters. In **DecodedMode**
        , '%' stand for themselves and encoded characters are not possible.

        **QUrl::DecodedMode**  should be used when setting the user name from a
        data source which is not a URL, such as a password dialog shown to the
        user or with a user name obtained by calling **userName** () with the
        **QUrl::FullyDecoded**  formatting option.

        **See also** **userName** () and **setUserInfo** ().
        """
        ...

    def userInfo(self, options: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#userInfo

        **QString QUrl::userInfo(QUrl::ComponentFormattingOptions options =
        PrettyDecoded) const**

        Returns the user info of the URL, or an empty string if the user info is
        undefined.

        This function returns an unambiguous value, which may contain that
        characters still percent-encoded, plus some control sequences not
        representable in decoded form in **QString** .

        The **options** argument controls how to format the user info component.
        The value of **QUrl::FullyDecoded**  is not permitted in this function.
        If you need to obtain fully decoded data, call **userName** () and
        **password** () individually.

        **See also** **setUserInfo** (), **userName** (), **password** (), and
        **authority** ().
        """
        ...

    def setUserInfo(self, userInfo: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setUserInfo

        **void QUrl::setUserInfo(const QString & userInfo , QUrl::ParsingMode
        mode = TolerantMode)**

        Sets the user info of the URL to **userInfo**. The user info is an
        optional part of the authority of the URL, as described in
        **setAuthority** ().

        The user info consists of a user name and optionally a password,
        separated by a ':'. If the password is empty, the colon must be omitted.
        The following example shows a valid user info string:

        ![](images/qurl-authority3.png)

        The **userInfo** data is interpreted according to **mode** : in
        **StrictMode** , any '%' characters must be followed by exactly two
        hexadecimal characters and some characters (including space) are not
        allowed in undecoded form. In **TolerantMode**  (the default), all
        characters are accepted in undecoded form and the tolerant parser will
        correct stray '%' not followed by two hex characters.

        This function does not allow **mode** to be **QUrl::DecodedMode** . To
        set fully decoded data, call **setUserName** () and **setPassword** ()
        individually.

        **See also** **userInfo** (), **setUserName** (), **setPassword** (),
        and **setAuthority** ().
        """
        ...

    def authority(self, options: "QUrl.ComponentFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#authority

        **QString QUrl::authority(QUrl::ComponentFormattingOptions options =
        PrettyDecoded) const**

        Returns the authority of the URL if it is defined; otherwise an empty
        string is returned.

        This function returns an unambiguous value, which may contain that
        characters still percent-encoded, plus some control sequences not
        representable in decoded form in **QString** .

        The **options** argument controls how to format the user info component.
        The value of **QUrl::FullyDecoded**  is not permitted in this function.
        If you need to obtain fully decoded data, call **userName** (),
        **password** (), **host** () and **port** () individually.

        **See also** **setAuthority** (), **userInfo** (), **userName** (),
        **password** (), **host** (), and **port** ().
        """
        ...

    def setAuthority(self, authority: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setAuthority

        **void QUrl::setAuthority(const QString & authority , QUrl::ParsingMode
        mode = TolerantMode)**

        Sets the authority of the URL to **authority**.

        The authority of a URL is the combination of user info, a host name and
        a port. All of these elements are optional; an empty authority is
        therefore valid.

        The user info and host are separated by a '@', and the host and port are
        separated by a ':'. If the user info is empty, the '@' must be omitted;
        although a stray ':' is permitted if the port is empty.

        The following example shows a valid authority string:

        ![](images/qurl-authority.png)

        The **authority** data is interpreted according to **mode** : in
        **StrictMode** , any '%' characters must be followed by exactly two
        hexadecimal characters and some characters (including space) are not
        allowed in undecoded form. In **TolerantMode**  (the default), all
        characters are accepted in undecoded form and the tolerant parser will
        correct stray '%' not followed by two hex characters.

        This function does not allow **mode** to be **QUrl::DecodedMode** . To
        set fully decoded data, call **setUserName** (), **setPassword** (),
        **setHost** () and **setPort** () individually.

        **See also** **authority** (), **setUserInfo** (), **setHost** (), and
        **setPort** ().
        """
        ...

    def scheme(self) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#scheme

        **QString QUrl::scheme() const**

        Returns the scheme of the URL. If an empty string is returned, this
        means the scheme is undefined and the URL is then relative.

        The scheme can only contain US-ASCII letters or digits, which means it
        cannot contain any character that would otherwise require encoding.
        Additionally, schemes are always returned in lowercase form.

        **See also** **setScheme** () and **isRelative** ().
        """
        ...

    def setScheme(self, scheme: str) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setScheme

        **void QUrl::setScheme(const QString & scheme )**

        Sets the scheme of the URL to **scheme**. As a scheme can only contain
        ASCII characters, no conversion or decoding is done on the input. It
        must also start with an ASCII letter.

        The scheme describes the type (or protocol) of the URL. It's represented
        by one or more ASCII characters at the start the URL.

        A scheme is strictly **RFC 3986** -compliant: `scheme = ALPHA *( ALPHA /
        DIGIT / "+" / "-" / "." )`

        The following example shows a URL where the scheme is "ftp":

        ![](images/qurl-authority2.png)

        To set the scheme, the following call is used:

        **QUrl**  url;
                url.setScheme("ftp");

        The scheme can also be empty, in which case the URL is interpreted as
        relative.

        **See also** **scheme** () and **isRelative** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#clear

        **void QUrl::clear()**

        Resets the content of the **QUrl** . After calling this function, the
        **QUrl**  is equal to one that has been constructed with the default
        empty constructor.

        **See also** **isEmpty** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qurl.html#isEmpty

        **bool QUrl::isEmpty() const**

        Returns `true` if the URL has no data; otherwise returns `false`.

        **See also** **clear** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qurl.html#isValid

        **bool QUrl::isValid() const**

        Returns `true` if the URL is non-empty and valid; otherwise returns
        `false`.

        The URL is run through a conformance test. Every part of the URL must
        conform to the standard encoding rules of the URI standard for the URL
        to be reported as valid.

        bool checkUrl(const **QUrl**  &url) {
                if (!url.isValid()) {
        **qDebug** ("Invalid URL: %s", qUtf8Printable(url.toString()));
        return false;
                }

                return true;
            }
        """
        ...

    def setUrl(self, url: str, mode: "QUrl.ParsingMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qurl.html#setUrl

        **void QUrl::setUrl(const QString & url , QUrl::ParsingMode parsingMode
        = TolerantMode)**

        Parses **url** and sets this object to that value. **QUrl**  will
        automatically percent encode all characters that are not allowed in a
        URL and decode the percent-encoded sequences that represent an
        unreserved character (letters, digits, hyphens, underscores, dots and
        tildes). All other characters are left in their original forms.

        Parses the **url** using the parser mode **parsingMode**. In
        **TolerantMode**  (the default), **QUrl**  will correct certain
        mistakes, notably the presence of a percent character ('%') not followed
        by two hexadecimal digits, and it will accept any character in any
        position. In **StrictMode** , encoding mistakes will not be tolerated
        and **QUrl**  will also check that certain forbidden characters are not
        present in unencoded form. If an error is detected in **StrictMode** ,
        **isValid** () will return false. The parsing mode **DecodedMode**  is
        not permitted in this context and will produce a run-time warning.

        **See also** **url** () and **toString** ().
        """
        ...

    def url(self, options: "QUrl.UrlFormattingOption" = ...) -> str:
        """
        https://doc.qt.io/qt-6/qurl.html#url

        **QString QUrl::url(QUrl::FormattingOptions options =
        FormattingOptions(PrettyDecoded)) const**

        Returns a string representation of the URL. The output can be customized
        by passing flags with **options**. The option **QUrl::FullyDecoded**  is
        not permitted in this function since it would generate ambiguous data.

        The resulting **QString**  can be passed back to a **QUrl**  later on.

        Synonym for **toString** (options).

        **See also** **setUrl** (), **FormattingOptions** , **toEncoded** (),
        and **toString** ().
        """
        ...

    def __repr__(self) -> str:
        ...

    def __hash__(self) -> int:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QAbstractTextDocumentLayout(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html

    **Detailed Description**

    The standard layout provided by Qt can handle simple word processing
    including inline images, lists and tables.

    Some applications, e.g., a word processor or a DTP application might need
    more features than the ones provided by Qt's layout engine, in which case
    you can subclass QAbstractTextDocumentLayout to provide custom layout
    behavior for your text documents.

    An instance of the QAbstractTextDocumentLayout subclass can be installed on
    a **QTextDocument**  object with the **setDocumentLayout** () function.

    You can insert custom objects into a **QTextDocument** ; see the
    **QTextObjectInterface**  class description for details.

    **See also** **QTextObjectInterface** .
    """

    class Selection(PyQt6.sip.simplewrapper):
        cursor = ...
        format = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QAbstractTextDocumentLayout.Selection") -> None:
            ...

    class PaintContext(PyQt6.sip.simplewrapper):
        clip: QtCore = ...
        cursorPosition: int = ...
        palette = ...
        selections: typing = ...

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QAbstractTextDocumentLayout.PaintContext") -> None:
            ...

    def __init__(self, doc: "QTextDocument") -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#QAbstractTextDoc
        umentLayout

        **QAbstractTextDocumentLayout::QAbstractTextDocumentLayout(QTextDocument
        * document )**

        Creates a new text document layout for the given **document**.
        """
        ...

    def blockWithMarkerAt(self, pos: QtCore.QPointF) -> "QTextBlock":
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#blockWithMarkerA
        t

        **[since 5.14] QTextBlock
        QAbstractTextDocumentLayout::blockWithMarkerAt(const QPointF & pos )
        const**

        Returns the block (probably a list item) whose **marker**  is found at
        the given position **pos**.

        This function was introduced in Qt 5.14.
        """
        ...

    def formatAt(self, pos: QtCore.QPointF) -> "QTextFormat":
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#formatAt

        **[since 5.8] QTextFormat QAbstractTextDocumentLayout::formatAt(const
        QPointF & pos ) const**

        Returns the text format at the given position **pos**.

        This function was introduced in Qt 5.8.
        """
        ...

    def imageAt(self, pos: QtCore.QPointF) -> str:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#imageAt

        **[since 5.8] QString QAbstractTextDocumentLayout::imageAt(const QPointF
        & pos ) const**

        Returns the source of the image at the given position **pos** , or an
        empty string if no image exists at that point.

        This function was introduced in Qt 5.8.
        """
        ...

    def format(self, pos: int) -> "QTextCharFormat":
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#format

        **[protected] QTextCharFormat QAbstractTextDocumentLayout::format(int
        position )**

        Returns the character format that is applicable at the given
        **position**.
        """
        ...

    def drawInlineObject(
        self,
        painter: "QPainter",
        rect: QtCore.QRectF,
        object: "QTextInlineObject",
        posInDocument: int,
        format: "QTextFormat",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#drawInlineObject

        **[virtual protected] void
        QAbstractTextDocumentLayout::drawInlineObject(QPainter * painter , const
        QRectF & rect , QTextInlineObject object , int posInDocument , const
        QTextFormat & format )**

        This function is called to draw the inline object, **object** , with the
        given **painter** within the rectangle specified by **rect** using the
        specified text **format**.

        **posInDocument** specifies the position of the object within the
        document.

        The default implementation calls drawObject() on the object handlers.
        This function is called only within Qt. Subclasses can reimplement this
        function to customize the drawing of inline objects.

        **See also** **draw** ().
        """
        ...

    def positionInlineObject(
        self, item: "QTextInlineObject", posInDocument: int, format: "QTextFormat"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#positionInlineOb
        ject

        **[virtual protected] void
        QAbstractTextDocumentLayout::positionInlineObject(QTextInlineObject item
        , int posInDocument , const QTextFormat & format )**

        Lays out the inline object **item** using the given text **format**.

        **posInDocument** specifies the position of the object within the
        document.

        The default implementation does nothing. This function is called only
        within Qt. Subclasses can reimplement this function to customize the
        position of inline objects.

        **See also** **drawInlineObject** ().
        """
        ...

    def resizeInlineObject(
        self, item: "QTextInlineObject", posInDocument: int, format: "QTextFormat"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#resizeInlineObje
        ct

        **[virtual protected] void
        QAbstractTextDocumentLayout::resizeInlineObject(QTextInlineObject item ,
        int posInDocument , const QTextFormat & format )**

        Sets the size of the inline object **item** corresponding to the text
        **format**.

        **posInDocument** specifies the position of the object within the
        document.

        The default implementation resizes the **item** to the size returned by
        the object handler's intrinsicSize() function. This function is called
        only within Qt. Subclasses can reimplement this function to customize
        the resizing of inline objects.
        """
        ...

    def documentChanged(self, from_: int, charsRemoved: int, charsAdded: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#documentChanged

        **[pure virtual protected] void
        QAbstractTextDocumentLayout::documentChanged(int position , int
        charsRemoved , int charsAdded )**

        This function is called whenever the contents of the document change. A
        change occurs when text is inserted, removed, or a combination of these
        two. The change is specified by **position** , **charsRemoved** , and
        **charsAdded** corresponding to the starting character position of the
        change, the number of characters removed from the document, and the
        number of characters added.

        For example, when inserting the text "Hello" into an empty document,
        **charsRemoved** would be 0 and **charsAdded** would be 5 (the length of
        the string).

        Replacing text is a combination of removing and inserting. For example,
        if the text "Hello" gets replaced by "Hi", **charsRemoved** would be 5
        and **charsAdded** would be 2.

        For subclasses of **QAbstractTextDocumentLayout** , this is the central
        function where a large portion of the work to lay out and position
        document contents is done.

        For example, in a subclass that only arranges blocks of text, an
        implementation of this function would have to do the following:

        * Determine the list of changed **QTextBlock** (s) using the parameters
        provided.
          * Each **QTextBlock**  object's corresponding
        **QTextLayout**  object needs to be processed. You can access the
        **QTextBlock** 's layout using the **QTextBlock::layout** () function.
        This processing should take the document's page size into consideration.
        * If the total number of pages changed, the **pageCountChanged** ()
        signal should be emitted.
          * If the total size changed, the
        **documentSizeChanged** () signal should be emitted.
          * The **update**
        () signal should be emitted to schedule a repaint of areas in the layout
        that require repainting.

        **See also** **QTextLayout** .
        """
        ...

    def handlerForObject(self, objectType: int) -> "QTextObjectInterface":
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#handlerForObject

        **QTextObjectInterface
        *QAbstractTextDocumentLayout::handlerForObject(int objectType ) const**

        Returns a handler for objects of the given **objectType**.
        """
        ...

    def unregisterHandler(
        self, objectType: int, component: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#unregisterHandle
        r

        **[since 5.2] void QAbstractTextDocumentLayout::unregisterHandler(int
        objectType , QObject * component = nullptr)**

        Unregisters the given **component** as a handler for items of the given
        **objectType** , or any handler if the **component** is not specified.

        This function was introduced in Qt 5.2.
        """
        ...

    def registerHandler(self, objectType: int, component: QtCore.QObject) -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#registerHandler

        **void QAbstractTextDocumentLayout::registerHandler(int objectType ,
        QObject * component )**

        Registers the given **component** as a handler for items of the given
        **objectType**.

        **Note:** registerHandler() has to be called once for each object type.
        This means that there is only one handler for multiple replacement
        characters of the same object type.

        The text document layout does not take ownership of `component`.
        """
        ...

    def document(self) -> "QTextDocument":
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#document

        **QTextDocument *QAbstractTextDocumentLayout::document() const**

        Returns the text document that this layout is operating on.
        """
        ...

    def paintDevice(self) -> "QPaintDevice":
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#paintDevice

        **QPaintDevice *QAbstractTextDocumentLayout::paintDevice() const**

        Returns the paint device used to render the document's layout.

        **See also** **setPaintDevice** ().
        """
        ...

    def setPaintDevice(self, device: "QPaintDevice") -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#setPaintDevice

        **void QAbstractTextDocumentLayout::setPaintDevice(QPaintDevice * device
        )**

        Sets the paint device used for rendering the document's layout to the
        given **device**.

        **See also** **paintDevice** ().
        """
        ...

    def blockBoundingRect(self, block: "QTextBlock") -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#blockBoundingRec
        t

        **[pure virtual] QRectF
        QAbstractTextDocumentLayout::blockBoundingRect(const QTextBlock & block
        ) const**

        Returns the bounding rectangle of **block**.
        """
        ...

    def frameBoundingRect(self, frame: "QTextFrame") -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#frameBoundingRec
        t

        **[pure virtual] QRectF
        QAbstractTextDocumentLayout::frameBoundingRect(QTextFrame * frame )
        const**

        Returns the bounding rectangle of **frame**.
        """
        ...

    def documentSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#documentSize

        **[pure virtual] QSizeF QAbstractTextDocumentLayout::documentSize()
        const**

        Returns the total size of the document's layout.

        This information can be used by display widgets to update their scroll
        bars correctly.

        **See also** **documentSizeChanged** () and **QTextDocument::pageSize**
        .
        """
        ...

    def pageCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#pageCount

        **[pure virtual] int QAbstractTextDocumentLayout::pageCount() const**

        Returns the number of pages contained in the layout.

        **See also** **pageCountChanged** ().
        """
        ...

    def anchorAt(self, pos: QtCore.QPointF) -> str:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#anchorAt

        **QString QAbstractTextDocumentLayout::anchorAt(const QPointF & position
        ) const**

        Returns the reference of the anchor the given **position** , or an empty
        string if no anchor exists at that point.
        """
        ...

    def hitTest(
        self, point: QtCore.QPointF, accuracy: QtCore.Qt.HitTestAccuracy
    ) -> int:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#hitTest

        **[pure virtual] int QAbstractTextDocumentLayout::hitTest(const QPointF
        & point , Qt::HitTestAccuracy accuracy ) const**

        Returns the cursor position for the given **point** with the specified
        **accuracy**. Returns -1 if no valid cursor position was found.
        """
        ...

    def draw(
        self, painter: "QPainter", context: "QAbstractTextDocumentLayout.PaintContext"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#draw

        **[pure virtual] void QAbstractTextDocumentLayout::draw(QPainter *
        painter , const QAbstractTextDocumentLayout::PaintContext & context )**

        Draws the layout with the given **painter** using the given **context**.
        """
        ...

    @property
    def documentSizeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#documentSizeChan
        ged

        **[signal] void QAbstractTextDocumentLayout::documentSizeChanged(const
        QSizeF & newSize )**

        This signal is emitted when the size of the document layout changes to
        **newSize**.

        Subclasses of **QAbstractTextDocumentLayout**  should emit this signal
        when the document's entire layout size changes. This signal is useful
        for widgets that display text documents since it enables them to update
        their scroll bars correctly.

        **See also** **documentSize** ().
        """
        ...

    @property
    def pageCountChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#pageCountChanged

        **[signal] void QAbstractTextDocumentLayout::pageCountChanged(int
        newPages )**

        This signal is emitted when the number of pages in the layout changes;
        **newPages** is the updated page count.

        Subclasses of **QAbstractTextDocumentLayout**  should emit this signal
        when the number of pages in the layout has changed. Changes to the page
        count are caused by changes to the layout or the document content
        itself.

        **See also** **pageCount** ().
        """
        ...

    @property
    def update(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#update

        **[signal] void QAbstractTextDocumentLayout::update(const QRectF & rect
        = QRectF(0., 0., 1000000000., 1000000000.))**

        This signal is emitted when the rectangle **rect** has been updated.

        Subclasses of **QAbstractTextDocumentLayout**  should emit this signal
        when the layout of the contents change in order to repaint.
        """
        ...

    @property
    def updateBlock(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qabstracttextdocumentlayout.html#updateBlock

        **[signal] void QAbstractTextDocumentLayout::updateBlock(const
        QTextBlock & block )**

        This signal is emitted when the specified **block** has been updated.

        Subclasses of **QAbstractTextDocumentLayout**  should emit this signal
        when the layout of **block** has changed in order to repaint.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QIdentityProxyModel(QAbstractProxyModel):
    """
    https://doc.qt.io/qt-6/qidentityproxymodel.html

    **Detailed Description**

    QIdentityProxyModel can be used to forward the structure of a source model
    exactly, with no sorting, filtering or other transformation. This is similar
    in concept to an identity matrix where A.I = A.

    Because it does no sorting or filtering, this class is most suitable to
    proxy models which transform the **data** () of the source model. For
    example, a proxy model could be created to define the font used, or the
    background colour, or the tooltip etc. This removes the need to implement
    all data handling in the same class that creates the structure of the model,
    and can also be used to create re-usable components.

    This also provides a way to change the data in the case where a source model
    is supplied by a third party which cannot be modified.

    class DateFormatProxyModel : public **QIdentityProxyModel**
        {
          //
    ...

          void setDateFormatString(const **QString**  &formatString)
    {
            m_formatString = formatString;
          }

          **QVariant**
    data(const **QModelIndex**  &index, int role) const override
          {
    if (role != Qt::DisplayRole)
              return **QIdentityProxyModel**
    ::data(index, role);

            const **QDateTime**  dateTime =
    sourceModel()->data(SourceClass::DateRole).toDateTime();

            return
    dateTime.toString(m_formatString);
          }

        private:
    **QString**  m_formatString;
        };

    **See also** **QAbstractProxyModel** , **Model/View Programming** , and
    **QAbstractItemModel** .
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#QIdentityProxyModel

        **QIdentityProxyModel::QIdentityProxyModel(QObject * parent = nullptr)**

        Constructs an identity model with the given **parent**.
        """
        ...

    def moveColumns(
        self,
        sourceParent: QModelIndex,
        sourceColumn: int,
        count: int,
        destinationParent: QModelIndex,
        destinationChild: int,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#moveColumns

        **[override virtual, since 5.15] bool
        QIdentityProxyModel::moveColumns(const QModelIndex & sourceParent , int
        sourceColumn , int count , const QModelIndex & destinationParent , int
        destinationChild )**

        Reimplements: **QAbstractItemModel::moveColumns** (const QModelIndex
        &sourceParent, int sourceColumn, int count, const QModelIndex
        &destinationParent, int destinationChild).

        This function was introduced in Qt 5.15.
        """
        ...

    def moveRows(
        self,
        sourceParent: QModelIndex,
        sourceRow: int,
        count: int,
        destinationParent: QModelIndex,
        destinationChild: int,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#moveRows

        **[override virtual, since 5.15] bool
        QIdentityProxyModel::moveRows(const QModelIndex & sourceParent , int
        sourceRow , int count , const QModelIndex & destinationParent , int
        destinationChild )**

        Reimplements: **QAbstractItemModel::moveRows** (const QModelIndex
        &sourceParent, int sourceRow, int count, const QModelIndex
        &destinationParent, int destinationChild).

        This function was introduced in Qt 5.15.
        """
        ...

    def sibling(self, row: int, column: int, idx: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#sibling

        **[override virtual] QModelIndex QIdentityProxyModel::sibling(int row ,
        int column , const QModelIndex & idx ) const**

        Reimplements: **QAbstractProxyModel::sibling(int row, int column, const
        QModelIndex &idx) const** .
        """
        ...

    def headerData(
        self, section: int, orientation: Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#headerData

        **[override virtual] QVariant QIdentityProxyModel::headerData(int
        section , Qt::Orientation orientation , int role = Qt::DisplayRole)
        const**

        Reimplements: **QAbstractProxyModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .
        """
        ...

    def removeRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#removeRows

        **[override virtual] bool QIdentityProxyModel::removeRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def removeColumns(self, column: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#removeColumns

        **[override virtual] bool QIdentityProxyModel::removeColumns(int column
        , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def insertRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#insertRows

        **[override virtual] bool QIdentityProxyModel::insertRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def insertColumns(self, column: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#insertColumns

        **[override virtual] bool QIdentityProxyModel::insertColumns(int column
        , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def setSourceModel(self, sourceModel: QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#setSourceModel

        **[override virtual] void
        QIdentityProxyModel::setSourceModel(QAbstractItemModel * newSourceModel
        )**

        Reimplements: **QAbstractProxyModel::setSourceModel**
        (QAbstractItemModel *sourceModel).
        """
        ...

    def match(
        self,
        start: QModelIndex,
        role: int,
        value: typing.Any,
        hits: int = ...,
        flags: Qt.MatchFlag = ...,
    ) -> typing.List[QModelIndex]:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#match

        **[override virtual] QModelIndexList QIdentityProxyModel::match(const
        QModelIndex & start , int role , const QVariant & value , int hits = 1,
        Qt::MatchFlags flags =
        Qt::MatchFlags(Qt::MatchStartsWith|Qt::MatchWrap)) const**

        Reimplements: **QAbstractItemModel::match(const QModelIndex &start, int
        role, const QVariant &value, int hits, Qt::MatchFlags flags) const** .
        """
        ...

    def mapSelectionToSource(self, selection: "QItemSelection") -> "QItemSelection":
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#mapSelectionToSource

        **[override virtual] QItemSelection
        QIdentityProxyModel::mapSelectionToSource(const QItemSelection &
        selection ) const**

        Reimplements: **QAbstractProxyModel::mapSelectionToSource(const
        QItemSelection &proxySelection) const** .
        """
        ...

    def mapSelectionFromSource(self, selection: "QItemSelection") -> "QItemSelection":
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#mapSelectionFromSource

        **[override virtual] QItemSelection
        QIdentityProxyModel::mapSelectionFromSource(const QItemSelection &
        selection ) const**

        Reimplements: **QAbstractProxyModel::mapSelectionFromSource(const
        QItemSelection &sourceSelection) const** .
        """
        ...

    def dropMimeData(
        self,
        data: "QMimeData",
        action: Qt.DropAction,
        row: int,
        column: int,
        parent: QModelIndex,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#dropMimeData

        **[override virtual] bool QIdentityProxyModel::dropMimeData(const
        QMimeData * data , Qt::DropAction action , int row , int column , const
        QModelIndex & parent )**

        Reimplements: **QAbstractProxyModel::dropMimeData** (const QMimeData
        *data, Qt::DropAction action, int row, int column, const QModelIndex
        &parent).
        """
        ...

    def rowCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#rowCount

        **[override virtual] int QIdentityProxyModel::rowCount(const QModelIndex
        & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .
        """
        ...

    def parent(self, child: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#parent

        **[override virtual] QModelIndex QIdentityProxyModel::parent(const
        QModelIndex & child ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    def mapToSource(self, proxyIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#mapToSource

        **[override virtual] QModelIndex QIdentityProxyModel::mapToSource(const
        QModelIndex & proxyIndex ) const**

        Reimplements: **QAbstractProxyModel::mapToSource(const QModelIndex
        &proxyIndex) const** .
        """
        ...

    def mapFromSource(self, sourceIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#mapFromSource

        **[override virtual] QModelIndex
        QIdentityProxyModel::mapFromSource(const QModelIndex & sourceIndex )
        const**

        Reimplements: **QAbstractProxyModel::mapFromSource(const QModelIndex
        &sourceIndex) const** .
        """
        ...

    def index(self, row: int, column: int, parent: QModelIndex = ...) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#index

        **[override virtual] QModelIndex QIdentityProxyModel::index(int row ,
        int column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .
        """
        ...

    def columnCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qidentityproxymodel.html#columnCount

        **[override virtual] int QIdentityProxyModel::columnCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtQuick import *


class QSGOpacityNode(QSGNode):
    """
    https://doc.qt.io/qt-6/qsgopacitynode.html

    **Detailed Description**

    Opacity applies to its subtree and can be nested. Multiple opacity nodes
    will be accumulated by multiplying their opacity. The accumulation happens
    as part of the rendering.

    When nested opacity gets below a certain threshold, the subtree might be
    marked as blocked, causing **isSubtreeBlocked** () to return true. This is
    done for performance reasons.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsgopacitynode.html#QSGOpacityNode

        **QSGOpacityNode::QSGOpacityNode()**

        Constructs an opacity node with a default opacity of 1.

        Opacity accumulates downwards in the scene graph so a node with two
        QSGOpacityNode instances above it, both with opacity of 0.5, will have
        effective opacity of 0.25.

        The default opacity of nodes is 1.
        """
        ...

    def opacity(self) -> float:
        """
        https://doc.qt.io/qt-6/qsgopacitynode.html#opacity

        **qreal QSGOpacityNode::opacity() const**

        Returns this opacity node's opacity.

        **See also** **setOpacity** ().
        """
        ...

    def setOpacity(self, opacity: float) -> None:
        """
        https://doc.qt.io/qt-6/qsgopacitynode.html#setOpacity

        **void QSGOpacityNode::setOpacity(qreal opacity )**

        Sets the opacity of this node to **opacity**.

        Before rendering the graph, the renderer will do an update pass over the
        subtree to propagate the opacity to its children.

        The value will be bounded to the range 0 to 1.

        **See also** **opacity** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QColorSpace(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcolorspace.html

    **Detailed Description**

    Color values can be interpreted in different ways, and based on the
    interpretation can live in different spaces. We call this **color spaces**.

    QColorSpace provides access to creating several predefined color spaces and
    can generate QColorTransforms for converting colors from one color space to
    another.

    QColorSpace can also represent color spaces defined by ICC profiles or
    embedded in images, that do not otherwise fit the predefined color spaces.

    A color space can generally speaking be conceived as a combination of set of
    primary colors and a transfer function. The primaries defines the axes of
    the color space, and the transfer function how values are mapped on the
    axes. The primaries are defined by three primary colors that represent
    exactly how red, green, and blue look in this particular color space, and a
    white color that represents where and how bright pure white is. The range of
    colors expressible by the primary colors is called the gamut, and a color
    space that can represent a wider range of colors is also known as a wide-
    gamut color space.

    The transfer function or gamma curve determines how each component in the
    color space is encoded. These are used because human perception does not
    operate linearly, and the transfer functions try to ensure that colors will
    seem evenly spaced to human eyes.
    """

    class TransferFunction(enum.Enum):
        Custom: QColorSpace = ...
        Linear: QColorSpace = ...
        Gamma: QColorSpace = ...
        SRgb: QColorSpace = ...
        ProPhotoRgb: QColorSpace = ...

    class Primaries(enum.Enum):
        Custom: QColorSpace = ...
        SRgb: QColorSpace = ...
        AdobeRgb: QColorSpace = ...
        DciP3D65: QColorSpace = ...
        ProPhotoRgb: QColorSpace = ...

    class NamedColorSpace(enum.Enum):
        SRgb: QColorSpace = ...
        SRgbLinear: QColorSpace = ...
        AdobeRgb: QColorSpace = ...
        DisplayP3: QColorSpace = ...
        ProPhotoRgb: QColorSpace = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace

        **QColorSpace::QColorSpace()**

        Creates a new colorspace object that represents an undefined and invalid
        colorspace.
        """
        ...

    @typing.overload
    def __init__(self, namedColorSpace: "QColorSpace.NamedColorSpace") -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace-1

        **QColorSpace::QColorSpace(QColorSpace::NamedColorSpace namedColorSpace
        )**

        Creates a new colorspace object that represents a **namedColorSpace**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        primaries: "QColorSpace.Primaries",
        fun: "QColorSpace.TransferFunction",
        gamma: float = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace-2

        **QColorSpace::QColorSpace(QColorSpace::Primaries primaries ,
        QColorSpace::TransferFunction transferFunction , float gamma = 0.0f)**

        Creates a custom color space with the primaries **primaries** , using
        the transfer function **transferFunction** and optionally **gamma**.
        """
        ...

    @typing.overload
    def __init__(self, primaries: "QColorSpace.Primaries", gamma: float) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace-3

        **QColorSpace::QColorSpace(QColorSpace::Primaries primaries , float
        gamma )**

        Creates a custom color space with the primaries **primaries** , using a
        gamma transfer function of **gamma**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        primaries: "QColorSpace.Primaries",
        transferFunctionTable: typing.Iterable[int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace-4

        **[since 6.1] QColorSpace::QColorSpace(QColorSpace::Primaries gamut ,
        const QList<uint16_t> & transferFunctionTable )**

        Creates a custom color space with the primaries **gamut** , using a
        custom transfer function described by **transferFunctionTable**.

        The table should contain at least 2 values, and contain an monotonically
        increasing list of values from 0 to 65535.

        This function was introduced in Qt 6.1.
        """
        ...

    @typing.overload
    def __init__(
        self,
        whitePoint: QtCore.QPointF,
        redPoint: QtCore.QPointF,
        greenPoint: QtCore.QPointF,
        bluePoint: QtCore.QPointF,
        fun: "QColorSpace.TransferFunction",
        gamma: float = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace-5

        **QColorSpace::QColorSpace(const QPointF & whitePoint , const QPointF &
        redPoint , const QPointF & greenPoint , const QPointF & bluePoint ,
        QColorSpace::TransferFunction transferFunction , float gamma = 0.0f)**

        Creates a custom colorspace with a primaries based on the chromaticities
        of the primary colors **whitePoint** , **redPoint** , **greenPoint** and
        **bluePoint** , and using the transfer function **transferFunction** and
        optionally **gamma**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        whitePoint: QtCore.QPointF,
        redPoint: QtCore.QPointF,
        greenPoint: QtCore.QPointF,
        bluePoint: QtCore.QPointF,
        redTransferFunctionTable: typing.Iterable[int],
        greenTransferFunctionTable: typing.Iterable[int],
        blueTransferFunctionTable: typing.Iterable[int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace-6

        **[since 6.1] QColorSpace::QColorSpace(const QPointF & whitePoint ,
        const QPointF & redPoint , const QPointF & greenPoint , const QPointF &
        bluePoint , const QList<uint16_t> & transferFunctionTable )**

        Creates a custom color space with primaries based on the chromaticities
        of the primary colors **whitePoint** , **redPoint** , **greenPoint** and
        **bluePoint** , and using the custom transfer function described by
        **transferFunctionTable**.

        This function was introduced in Qt 6.1.
        """
        ...

    @typing.overload
    def __init__(
        self,
        whitePoint: QtCore.QPointF,
        redPoint: QtCore.QPointF,
        greenPoint: QtCore.QPointF,
        bluePoint: QtCore.QPointF,
        transferFunctionTable: typing.Iterable[int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace-7

        **[since 6.1] QColorSpace::QColorSpace(const QPointF & whitePoint ,
        const QPointF & redPoint , const QPointF & greenPoint , const QPointF &
        bluePoint , const QList<uint16_t> & redTransferFunctionTable , const
        QList<uint16_t> & greenTransferFunctionTable , const QList<uint16_t> &
        blueTransferFunctionTable )**

        Creates a custom color space with primaries based on the chromaticities
        of the primary colors **whitePoint** , **redPoint** , **greenPoint** and
        **bluePoint** , and using the custom transfer functions described by
        **redTransferFunctionTable** , **greenTransferFunctionTable** , and
        **blueTransferFunctionTable**.

        This function was introduced in Qt 6.1.
        """
        ...

    @typing.overload
    def __init__(self, colorSpace: "QColorSpace") -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#QColorSpace

        **QColorSpace::QColorSpace()**

        Creates a new colorspace object that represents an undefined and invalid
        colorspace.
        """
        ...

    def setDescription(self, description: str) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#setDescription

        **[since 6.2] void QColorSpace::setDescription(const QString &
        description )**

        Sets the name or short description of the color space to
        **description**.

        If set to empty **description** () will return original or guessed
        descriptions instead.

        This function was introduced in Qt 6.2.

        **See also** **description** ().
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#description

        **[since 6.2] QString QColorSpace::description() const**

        Returns the name or short description. If a description hasn't been
        given in **setDescription** (), the original name of the profile is
        returned if the profile is unmodified, a guessed name is returned if the
        profile has been recognized as a known color space, otherwise an empty
        string is returned.

        This function was introduced in Qt 6.2.

        **See also** **setDescription** ().
        """
        ...

    def transformationToColorSpace(
        self, colorspace: "QColorSpace"
    ) -> "QColorTransform":
        """
        https://doc.qt.io/qt-6/qcolorspace.html#transformationToColorSpace

        **QColorTransform QColorSpace::transformationToColorSpace(const
        QColorSpace & colorspace ) const**

        Generates and returns a color space transformation from this color space
        to **colorspace**.
        """
        ...

    def iccProfile(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#iccProfile

        **QByteArray QColorSpace::iccProfile() const**

        Returns an ICC profile representing the color space.

        If the color space was generated from an ICC profile, that profile is
        returned, otherwise one is generated.

        **Note:** Even invalid color spaces may return the ICC profile if they
        were generated from one, to allow applications to implement wider
        support themselves.

        **See also** **fromIccProfile** ().
        """
        ...

    @staticmethod
    def fromIccProfile(iccProfile: QtCore.QByteArray) -> "QColorSpace":
        """
        https://doc.qt.io/qt-6/qcolorspace.html#fromIccProfile

        **[static] QColorSpace QColorSpace::fromIccProfile(const QByteArray &
        iccProfile )**

        Creates a **QColorSpace**  from ICC profile **iccProfile**.

        **Note:** Not all ICC profiles are supported. **QColorSpace**  only
        supports RGB-XYZ ICC profiles that are three-component matrix-based.

        If the ICC profile is not supported an invalid **QColorSpace**  is
        returned where you can still read the original ICC profile using
        **iccProfile** ().

        **See also** **iccProfile** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#isValid

        **bool QColorSpace::isValid() const**

        Returns `true` if the color space is valid.
        """
        ...

    @typing.overload
    def setPrimaries(self, primariesId: "QColorSpace.Primaries") -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#setPrimaries

        **void QColorSpace::setPrimaries(QColorSpace::Primaries primariesId )**

        Sets the primaries to those of the **primariesId** set.

        **See also** **primaries** ().
        """
        ...

    @typing.overload
    def setPrimaries(
        self,
        whitePoint: QtCore.QPointF,
        redPoint: QtCore.QPointF,
        greenPoint: QtCore.QPointF,
        bluePoint: QtCore.QPointF,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#setPrimaries-1

        **void QColorSpace::setPrimaries(const QPointF & whitePoint , const
        QPointF & redPoint , const QPointF & greenPoint , const QPointF &
        bluePoint )**

        Set primaries to the chromaticities of **whitePoint** , **redPoint** ,
        **greenPoint** and **bluePoint**.

        **See also** **primaries** ().
        """
        ...

    def withTransferFunctions(
        self,
        redTransferFunctionTable: typing.Iterable[int],
        greenTransferFunctionTable: typing.Iterable[int],
        blueTransferFunctionTable: typing.Iterable[int],
    ) -> "QColorSpace":
        """
        https://doc.qt.io/qt-6/qcolorspace.html#withTransferFunctions

        **[since 6.1] QColorSpace QColorSpace::withTransferFunctions(const
        QList<uint16_t> & redTransferFunctionTable , const QList<uint16_t> &
        greenTransferFunctionTable , const QList<uint16_t> &
        blueTransferFunctionTable ) const**

        Returns a copy of this color space, except using the transfer functions
        described by **redTransferFunctionTable** ,
        **greenTransferFunctionTable** and **blueTransferFunctionTable**.

        This function was introduced in Qt 6.1.

        **See also** **setTransferFunctions** ().
        """
        ...

    @typing.overload
    def withTransferFunction(
        self, transferFunctionTable: typing.Iterable[int]
    ) -> "QColorSpace":
        """
        https://doc.qt.io/qt-6/qcolorspace.html#withTransferFunction

        **QColorSpace
        QColorSpace::withTransferFunction(QColorSpace::TransferFunction
        transferFunction , float gamma = 0.0f) const**

        Returns a copy of this color space, except using the transfer function
        **transferFunction** and **gamma**.

        **See also** **transferFunction** (), **gamma** (), and
        **setTransferFunction** ().
        """
        ...

    @typing.overload
    def withTransferFunction(
        self, transferFunction: "QColorSpace.TransferFunction", gamma: float = ...
    ) -> "QColorSpace":
        """
        https://doc.qt.io/qt-6/qcolorspace.html#withTransferFunction-1

        **[since 6.1] QColorSpace QColorSpace::withTransferFunction(const
        QList<uint16_t> & transferFunctionTable ) const**

        Returns a copy of this color space, except using the transfer function
        described by **transferFunctionTable**.

        This function was introduced in Qt 6.1.

        **See also** **transferFunction** () and **setTransferFunction** ().
        """
        ...

    def setTransferFunctions(
        self,
        redTransferFunctionTable: typing.Iterable[int],
        greenTransferFunctionTable: typing.Iterable[int],
        blueTransferFunctionTable: typing.Iterable[int],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#setTransferFunctions

        **[since 6.1] void QColorSpace::setTransferFunctions(const
        QList<uint16_t> & redTransferFunctionTable , const QList<uint16_t> &
        greenTransferFunctionTable , const QList<uint16_t> &
        blueTransferFunctionTable )**

        Sets the transfer functions to **redTransferFunctionTable** ,
        **greenTransferFunctionTable** and **blueTransferFunctionTable**.

        This function was introduced in Qt 6.1.

        **See also** **withTransferFunctions** ().
        """
        ...

    @typing.overload
    def setTransferFunction(
        self, transferFunction: "QColorSpace.TransferFunction", gamma: float = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#setTransferFunction

        **void QColorSpace::setTransferFunction(QColorSpace::TransferFunction
        transferFunction , float gamma = 0.0f)**

        Sets the transfer function to **transferFunction** and **gamma**.

        **See also** **transferFunction** (), **gamma** (), and
        **withTransferFunction** ().
        """
        ...

    @typing.overload
    def setTransferFunction(self, transferFunctionTable: typing.Iterable[int]) -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#setTransferFunction-1

        **[since 6.1] void QColorSpace::setTransferFunction(const
        QList<uint16_t> & transferFunctionTable )**

        Sets the transfer function to **transferFunctionTable**.

        This function was introduced in Qt 6.1.

        **See also** **withTransferFunction** ().
        """
        ...

    def gamma(self) -> float:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#gamma

        **float QColorSpace::gamma() const**

        Returns the gamma value of color spaces with `TransferFunction::Gamma`,
        an approximate gamma value for other predefined color spaces, or 0.0 if
        no approximate gamma is known.

        **See also** **transferFunction** ().
        """
        ...

    def transferFunction(self) -> "QColorSpace.TransferFunction":
        """
        https://doc.qt.io/qt-6/qcolorspace.html#transferFunction

        **QColorSpace::TransferFunction QColorSpace::transferFunction() const**

        Returns the predefined transfer function of the color space or
        `TransferFunction::Custom` if it doesn't match any of them.

        **See also** **gamma** (), **setTransferFunction** (), and
        **withTransferFunction** ().
        """
        ...

    def primaries(self) -> "QColorSpace.Primaries":
        """
        https://doc.qt.io/qt-6/qcolorspace.html#primaries

        **QColorSpace::Primaries QColorSpace::primaries() const**

        Returns the predefined primaries of the color space or
        `primaries::Custom` if it doesn't match any of them.

        **See also** **setPrimaries** ().
        """
        ...

    def swap(self, colorSpace: "QColorSpace") -> None:
        """
        https://doc.qt.io/qt-6/qcolorspace.html#swap

        **void QColorSpace::swap(QColorSpace & other )**

        Swaps color space **other** with this color space. This operation is
        very fast and never fails.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
import datetime
from PyQt6.QtPositioning import *
import enum


class QGeoPositionInfo(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qgeopositioninfo.html

    **Detailed Description**

    A QGeoPositionInfo contains, at a minimum, a geographical coordinate and a
    timestamp. It may also have heading and speed measurements as well as
    estimates of the accuracy of the provided data.

    **See also** **QGeoPositionInfoSource** .
    """

    class Attribute(enum.Enum):
        Direction: QGeoPositionInfo = ...
        GroundSpeed: QGeoPositionInfo = ...
        VerticalSpeed: QGeoPositionInfo = ...
        MagneticVariation: QGeoPositionInfo = ...
        HorizontalAccuracy: QGeoPositionInfo = ...
        VerticalAccuracy: QGeoPositionInfo = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#QGeoPositionInfo

        **QGeoPositionInfo::QGeoPositionInfo()**

        Creates an invalid QGeoPositionInfo object.

        **See also** **isValid** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        coordinate: QGeoCoordinate,
        updateTime: typing.Union[QtCore.QDateTime, datetime.datetime],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#QGeoPositionInfo-1

        **QGeoPositionInfo::QGeoPositionInfo(const QGeoCoordinate & coordinate ,
        const QDateTime & timestamp )**

        Creates a QGeoPositionInfo for the given **coordinate** and
        **timestamp**.
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoPositionInfo") -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#QGeoPositionInfo-2

        **QGeoPositionInfo::QGeoPositionInfo(const QGeoPositionInfo & other )**

        Creates a QGeoPositionInfo with the values of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def swap(self, other: "QGeoPositionInfo") -> None:
        ...

    def hasAttribute(self, attribute: "QGeoPositionInfo.Attribute") -> bool:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#hasAttribute

        **bool QGeoPositionInfo::hasAttribute(QGeoPositionInfo::Attribute
        attribute ) const**

        Returns true if the specified **attribute** is present for this
        **QGeoPositionInfo**  object.
        """
        ...

    def removeAttribute(self, attribute: "QGeoPositionInfo.Attribute") -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#removeAttribute

        **void QGeoPositionInfo::removeAttribute(QGeoPositionInfo::Attribute
        attribute )**

        Removes the specified **attribute** and its value.
        """
        ...

    def attribute(self, attribute: "QGeoPositionInfo.Attribute") -> float:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#attribute

        **qreal QGeoPositionInfo::attribute(QGeoPositionInfo::Attribute
        attribute ) const**

        Returns the value of the specified **attribute** as a qreal value.

        Returns NaN if the value has not been set.

        The function **hasAttribute** () should be used to determine whether or
        not a value has been set for an attribute.

        **See also** **hasAttribute** () and **setAttribute** ().
        """
        ...

    def setAttribute(
        self, attribute: "QGeoPositionInfo.Attribute", value: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#setAttribute

        **void QGeoPositionInfo::setAttribute(QGeoPositionInfo::Attribute
        attribute , qreal value )**

        Sets the value for **attribute** to **value**.

        **See also** **attribute** ().
        """
        ...

    def coordinate(self) -> QGeoCoordinate:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#coordinate

        **QGeoCoordinate QGeoPositionInfo::coordinate() const**

        Returns the coordinate for this position.

        Returns an invalid coordinate if no coordinate has been set.

        **See also** **setCoordinate** ().
        """
        ...

    def setCoordinate(self, coordinate: QGeoCoordinate) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#setCoordinate

        **void QGeoPositionInfo::setCoordinate(const QGeoCoordinate & coordinate
        )**

        Sets the coordinate for this position to **coordinate**.

        **See also** **coordinate** ().
        """
        ...

    def timestamp(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#timestamp

        **QDateTime QGeoPositionInfo::timestamp() const**

        Returns the date and time at which this position was reported, in UTC
        time.

        Returns an invalid **QDateTime**  if no date/time value has been set.

        **See also** **setTimestamp** ().
        """
        ...

    def setTimestamp(
        self, timestamp: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#setTimestamp

        **void QGeoPositionInfo::setTimestamp(const QDateTime & timestamp )**

        Sets the date and time at which this position was reported to
        **timestamp**.

        The **timestamp** must be in UTC time.

        **See also** **timestamp** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgeopositioninfo.html#isValid

        **bool QGeoPositionInfo::isValid() const**

        Returns true if the **timestamp** () and **coordinate** () values are
        both valid.

        **See also** **QGeoCoordinate::isValid** () and **QDateTime::isValid**
        ().
        """
        ...
